@@ -12,6 +12,7 @@
 
 #include "mothur.h"
 #include "sequence.hpp"
+#include "utils.hpp"
 
 
 /***********************************************************************/
@@ -19,7 +20,7 @@
 class Filters {
 
 public:
-	Filters() { m = MothurOut::getInstance(); };
+    Filters() { m = MothurOut::getInstance(); numSeqs = 0; };
 	~Filters(){};
 		
 	string getFilter()			{	return filter;		}
@@ -89,18 +90,18 @@ public:
 
 	void doHard(string hard) {
 		ifstream fileHandle;
-		m->openInputFile(hard, fileHandle);
+        Utils util; util.openInputFile(hard, fileHandle);
 	
 		fileHandle >> filter;
 	
 		fileHandle.close();
         
-        if (filter.length() != alignmentLength) {  m->mothurOut("[ERROR]: Sequences are not all the same length as the filter, please correct.\n");  m->control_pressed = true; }
+        if (filter.length() != alignmentLength) {  m->mothurOut("[ERROR]: Sequences are not all the same length as the filter, please correct.\n");  m->setControl_pressed(true); }
 	}
 
 	void getFreqs(Sequence seq) {
 	
-		string curAligned = seq.getAligned();
+        string curAligned = seq.getAligned(); numSeqs++;
 	
 		for(int j=0;j<alignmentLength;j++){
 			if(toupper(curAligned[j]) == 'A')										{	a[j]++;		}
