@@ -8,7 +8,7 @@
  */
 
 #include "clusterclassic.h"
-#include "progress.hpp"
+
 #include "utils.hpp"
 
 /***********************************************************************/
@@ -61,13 +61,8 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		
 		//initialize distance matrix to cutoff
 		dMatrix.resize(nseqs);
-		//colDist temp(0, 0, aboveCutoff);
-		//rowSmallDists.resize(nseqs, temp);
-		for (int i = 1; i < nseqs; i++) {			
-			dMatrix[i].resize(i, aboveCutoff);		
-		}												
-														
-		
+		for (int i = 1; i < nseqs; i++) {	 dMatrix[i].resize(i, aboveCutoff);	 }
+        
 		char d;
 		while((d=fileHandle.get()) != EOF){
 
@@ -85,16 +80,15 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 				}
 		}
 
-		Progress* reading;
+		
 
 		if(square == 0){
 
-				reading = new Progress("Reading matrix:     ", nseqs * (nseqs - 1) / 2);
 
 				int        index = 0;
 
 				for(int i=1;i<nseqs;i++){
-						if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+						if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
 						
 						fileHandle >> name;
 						matrixNames.push_back(name);
@@ -106,21 +100,19 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						
 								for(int j=0;j<i;j++){
 								
-										if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
 										
 										fileHandle >> distance;
 							
-										if (distance == -1) { distance = 1000000; }
+										if (util.isEqual(distance,-1)) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
 								
-										//if(distance < cutoff){
-											dMatrix[i][j] = distance;
-											if (distance < smallDist) { smallDist = distance; }
-											//if (rowSmallDists[i].dist > distance) {  rowSmallDists[i].dist = distance; rowSmallDists[i].col = j; rowSmallDists[i].row = i; }
-											//if (rowSmallDists[j].dist > distance) {  rowSmallDists[j].dist = distance; rowSmallDists[j].col = i; rowSmallDists[j].row = j; }
-										//}
+										
+                                        dMatrix[i][j] = distance;
+                                        if (distance < smallDist) { smallDist = distance; }
+											
 										index++;
-										reading->update(index);
+										
 								}
 				
 						}
@@ -130,32 +122,29 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<i;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
 				
-										if (distance == -1) { distance = 1000000; }
+										if (util.isEqual(distance,-1)) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
 										
-										//if(distance < cutoff){
-											if (distance < smallDist) { smallDist = distance; }
+                                    
+                                        if (distance < smallDist) { smallDist = distance; }
+                                    
+                                        int row = nameMap->get(matrixNames[i]);
+                                        int col = nameMap->get(matrixNames[j]);
+                                    
+                                        if (row < col) {  dMatrix[col][row] = distance; }
+                                        else { dMatrix[row][col] = distance; }
 											
-											int row = nameMap->get(matrixNames[i]);
-											int col = nameMap->get(matrixNames[j]);
-											
-											if (row < col) {  dMatrix[col][row] = distance; }
-											else { dMatrix[row][col] = distance; }
-											
-											//if (rowSmallDists[row].dist > distance) {  rowSmallDists[row].dist = distance; rowSmallDists[row].col = col; rowSmallDists[row].row = row; }
-											//if (rowSmallDists[col].dist > distance) {  rowSmallDists[col].dist = distance; rowSmallDists[col].col = row; rowSmallDists[col].row = col; }
-										//}
 										index++;
-										reading->update(index);
+										
 								}
 						}
 				}
 		}
 		else{
 
-				reading = new Progress("Reading matrix:     ", nseqs * nseqs);
+				
 		
 				int index = nseqs;
 
@@ -168,20 +157,18 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();  return 0; }
 										
-										if (distance == -1) { distance = 1000000; }
+										if (util.isEqual(distance,-1)) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
 										
 										if(j < i){
 											if (distance < smallDist) { smallDist = distance; }
 											
 											dMatrix[i][j] = distance;
-											//if (rowSmallDists[i].dist > distance) {  rowSmallDists[i].dist = distance; rowSmallDists[i].col = j; rowSmallDists[i].row = i; }
-											//if (rowSmallDists[j].dist > distance) {  rowSmallDists[j].dist = distance; rowSmallDists[j].col = i; rowSmallDists[j].row = j; }
 										}
 										index++;
-										reading->update(index);
+										
 								}
 						
 						}
@@ -191,7 +178,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
 										
 									   if (distance == -1) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
@@ -204,21 +191,17 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 											
 											if (row < col) {  dMatrix[col][row] = distance; }
 											else { dMatrix[row][col] = distance; }
-											
-											//if (rowSmallDists[row].dist > distance) {  rowSmallDists[row].dist = distance; rowSmallDists[row].col = col; rowSmallDists[row].row = row; }
-											//if (rowSmallDists[col].dist > distance) {  rowSmallDists[col].dist = distance; rowSmallDists[col].col = row; rowSmallDists[col].row = col; }
 										}
 										index++;
-										reading->update(index);
+										
 								}
 						}
 				}
 		}
 		
-		if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();  return 0; }
+		
 		
-		reading->finish();
-		delete reading;
 
 		list->setLabel("0");
 		rabund = new RAbundVector(list->getRAbundVector());
@@ -285,16 +268,15 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
             }
 		}
         
-		Progress* reading;
+		
         
 		if(square == 0){
             
-            reading = new Progress("Reading matrix:     ", nseqs * (nseqs - 1) / 2);
             
             int        index = 0;
             
             for(int i=1;i<nseqs;i++){
-                if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+                if (m->getControl_pressed()) {  fileHandle.close(); return 0; }
                 
                 fileHandle >> name;
                 matrixNames.push_back(name);
@@ -306,21 +288,18 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     
                     for(int j=0;j<i;j++){
                         
-                        if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) { fileHandle.close(); return 0;  }
                         
                         fileHandle >> distance;
                         
-                        if (distance == -1) { distance = 1000000; }
+                        if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
                         
-                        //if(distance < cutoff){
+                        
                         dMatrix[i][j] = distance;
                         if (distance < smallDist) { smallDist = distance; }
-                        //if (rowSmallDists[i].dist > distance) {  rowSmallDists[i].dist = distance; rowSmallDists[i].col = j; rowSmallDists[i].row = i; }
-                        //if (rowSmallDists[j].dist > distance) {  rowSmallDists[j].dist = distance; rowSmallDists[j].col = i; rowSmallDists[j].row = j; }
-                        //}
-                        index++;
-                        reading->update(index);
+                                                index++;
+                        
                     }
                     
                 }
@@ -328,9 +307,9 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<i;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) { delete reading; fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
                         
-                        if (distance == -1) { distance = 1000000; }
+                        if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
                         
                         if (distance < smallDist) { smallDist = distance; }
@@ -342,14 +321,13 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                         else { dMatrix[row][col] = distance; }
                         
                         index++;
-                        reading->update(index);
+                        
                     }
                 }
             }
 		}
 		else{
             
-            reading = new Progress("Reading matrix:     ", nseqs * nseqs);
             
             int index = nseqs;
             
@@ -362,9 +340,9 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
                         
-                        if (distance == -1) { distance = 1000000; }
+                        if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
                         
                         if(j < i){
@@ -373,7 +351,6 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                             dMatrix[i][j] = distance;
                         }
                         index++;
-                        reading->update(index);
                     }
                     
                 }
@@ -382,9 +359,9 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
                         
-                        if (distance == -1) { distance = 1000000; }
+                        if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
                         
                         if(j < i){
@@ -397,16 +374,14 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                             else { dMatrix[row][col] = distance; }
                         }
                         index++;
-                        reading->update(index);
                     }
                 }
             }
 		}
 		
-		if (m->getControl_pressed()) {  fileHandle.close();  delete reading; return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+		
 		
-		reading->finish();
-		delete reading;
         
 		list->setLabel("0");
 		rabund = new RAbundVector();
@@ -448,28 +423,27 @@ double ClusterClassic::getSmallCell() {
 				if (dMatrix[i][j] < smallDist) {
 					mins.clear();
 					colDist temp(i, j, dMatrix[i][j]);
-					mins.push_back(temp); 
+					mins.push_back(temp);
+                    //cout << "adding " << i << '\t' << j << " to mins\n";
 					smallDist = dMatrix[i][j];
 				}else if (dMatrix[i][j] == smallDist) {
 					colDist temp(i, j, dMatrix[i][j]);
-					mins.push_back(temp); 
+					mins.push_back(temp);
+                    //cout << "adding " << i << '\t' << j << " to mins\n";
 
 				}
 			}
 		}
-		Utils util;
-		if (mins.size() > 0) {
-			int zrand = 0;
-			if (mins.size() > 1) {
-				//pick random number between 0 and mins.size()
-				zrand = util.getRandomIndex(mins.size()-1);
-			}
-			
-			smallRow = mins[zrand].row;
-			smallCol = mins[zrand].col;
-		
-		}
-	//cout << smallRow << '\t' << smallCol << '\t' << smallDist << endl;
+        
+        if (mins.size() != 0) {
+            Utils util; util.mothurRandomShuffle(mins);  //randomize the order of the iterators in the mins vector
+        
+            smallRow = mins[0].row;
+            smallCol = mins[0].col;
+        }
+        
+        //cout << "num mins = " << mins.size() << endl;
+        
 		//eliminate smallCell
 		if (smallRow < smallCol) { dMatrix[smallCol][smallRow] = aboveCutoff; }
 		else { dMatrix[smallRow][smallCol] = aboveCutoff; }
@@ -485,17 +459,9 @@ double ClusterClassic::getSmallCell() {
 /***********************************************************************/
 void ClusterClassic::clusterBins(){
 	try {
-	//	cout << smallCol << '\t' << smallRow << '\t' << smallDist << '\t' << rabund->get(smallRow) << '\t' << rabund->get(smallCol);
-
 		rabund->set(smallRow, rabund->get(smallRow)+rabund->get(smallCol));	
-		rabund->set(smallCol, 0);	
-		/*for (int i = smallCol+1; i < rabund->size(); i++) {
-			rabund->set((i-1), rabund->get(i));
-		}
-		rabund->resize((rabund->size()-1));*/
+		rabund->set(smallCol, 0);
 		rabund->setLabel(toString(smallDist));
-
-	//	cout << '\t' << rabund->get(smallRow) << '\t' << rabund->get(smallCol) << endl;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClusterClassic", "clusterBins");
@@ -505,18 +471,11 @@ void ClusterClassic::clusterBins(){
 /***********************************************************************/
 void ClusterClassic::clusterNames(){
 	try {
-	//	cout << smallCol << '\t' << smallRow << '\t' << smallDist << '\t' << list->get(smallRow) << '\t' << list->get(smallCol);
 		if (mapWanted) {  updateMap();  }
 		
 		list->set(smallRow, list->get(smallRow)+','+list->get(smallCol));
-		list->set(smallCol, "");	
-		/*for (int i = smallCol+1; i < list->size(); i++) {
-			list->set((i-1), list->get(i));
-		}
-		list->resize((list->size()-1));*/
+		list->set(smallCol, "");
 		list->setLabel(toString(smallDist));
-	
-	//	cout << '\t' << list->get(smallRow) << '\t' << list->get(smallCol) << endl;
     }
 	catch(exception& e) {
 		m->errorOut(e, "ClusterClassic", "clusterNames");
@@ -526,11 +485,13 @@ void ClusterClassic::clusterNames(){
 /***********************************************************************/
 void ClusterClassic::update(double& cutOFF){
 	try {
-//print();		
+		
 		getSmallCell();
 		
 		int r, c;
 		r = smallRow; c = smallCol;
+        
+        //cout << "smallest row / col = " << smallRow << '\t' << smallCol << endl;
 				
 		for(int i=0;i<nseqs;i++){
 			if(i != r && i != c){
@@ -555,7 +516,7 @@ void ClusterClassic::update(double& cutOFF){
 				else if (method == "nearest"){
 					newDist = min(distRow, distCol);
 				}
-				//cout << "newDist = " << newDist << endl;	
+					
 				if (i > r) { dMatrix[i][r] = newDist; }
 				else { dMatrix[r][i] = newDist; }
 				
@@ -564,24 +525,6 @@ void ClusterClassic::update(double& cutOFF){
 			
 		clusterBins();
 		clusterNames();
-		
-		//resize each row
-		/*for(int i=0;i<nseqs;i++){
-			for(int j=c+1;j<dMatrix[i].size();j++){
-				dMatrix[i][j-1]=dMatrix[i][j];
-			}
-		}			
-		
-		//resize each col
-		for(int i=c+1;i<nseqs;i++){
-			for(int j=0;j < dMatrix[i-1].size();j++){
-				dMatrix[i-1][j]=dMatrix[i][j];
-			}
-		}	
-		
-		nseqs--;
-		dMatrix.pop_back();*/
-
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClusterClassic", "update");
