@@ -69,7 +69,6 @@
 #include "makegroupcommand.h"
 #include "chopseqscommand.h"
 #include "clearcutcommand.h"
-#include "catchallcommand.h"
 #include "splitabundcommand.h"
 #include "clustersplitcommand.h"
 #include "classifyotucommand.h"
@@ -154,9 +153,8 @@
 #include "chimeravsearchcommand.h"
 #include "mergecountcommand.hpp"
 #include "clusterfitcommand.hpp"
+#include "mergeotuscommand.hpp"
 
-//needed for testing project
-//CommandFactory* CommandFactory::_uniqueInstance;
 
 /*******************************************************/
 
@@ -231,7 +229,6 @@ CommandFactory::CommandFactory(){
 	commands["make.group"]			= "make.group";
 	commands["chop.seqs"]			= "chop.seqs";
 	commands["clearcut"]			= "clearcut";
-	commands["catchall"]			= "catchall";
 	commands["split.abund"]			= "split.abund";
 	commands["classify.otu"]		= "classify.otu";
 	commands["degap.seqs"]			= "degap.seqs";
@@ -331,6 +328,7 @@ CommandFactory::CommandFactory(){
     commands["rename.file"]         = "rename.file";
     commands["merge.count"]         = "merge.count";
     commands["cluster.fit"]         = "cluster.fit";
+    commands["merge.otus"]         = "merge.otus";
 
 
 }
@@ -348,7 +346,7 @@ CommandFactory::~CommandFactory(){
 int CommandFactory::checkForRedirects(string optionString) {
     try {
         Utils util;
-        int pos = optionString.find("outputdir");
+        int pos = (int)optionString.find("outputdir");
         if (pos != string::npos) { //user has set outputdir in command option string
             string outputOption = "";
             bool foundEquals = false;
@@ -364,7 +362,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             }
         }
 
-        pos = optionString.find("inputdir");
+        pos = (int)optionString.find("inputdir");
         if (pos != string::npos) { //user has set inputdir in command option string
             string intputOption = "";
             bool foundEquals = false;
@@ -380,7 +378,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             }
         }
 
-        pos = optionString.find("seed=");
+        pos = (int)optionString.find("seed=");
         if (pos != string::npos) { //user has set seed in command option string
             string intputOption = "";
             bool foundEquals = false;
@@ -392,7 +390,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             if (intputOption[0] == '=') { intputOption = intputOption.substr(1); }
             bool seed = false; int random;
             if (intputOption == "clear") {
-                random = time(NULL);
+                random = (int)time(NULL);
                 seed = true;
             }else {
                 if (util.isNumeric1(intputOption)) { util.mothurConvert(intputOption, random); seed=true; }
@@ -402,7 +400,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             if (seed)  { m->mothurOut("Setting random seed to " + toString(random) + ".\n\n"); m->setRandomSeed(random); }
         }
         
-        pos = optionString.find("mothurcalling=true");
+        pos = (int)optionString.find("mothurcalling=true");
         if (pos != string::npos) { //user has set seed in command option string
             current->setMothurCalling(true);
         }else { current->setMothurCalling(false);  }
@@ -503,7 +501,6 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
 		else if(commandName == "make.group")			{	command = new MakeGroupCommand(optionString);				}
 		else if(commandName == "chop.seqs")				{	command = new ChopSeqsCommand(optionString);				}
 		else if(commandName == "clearcut")				{	command = new ClearcutCommand(optionString);				}
-		else if(commandName == "catchall")				{	command = new CatchAllCommand(optionString);				}
 		else if(commandName == "split.abund")			{	command = new SplitAbundCommand(optionString);				}
 		else if(commandName == "cluster.split")			{	command = new ClusterSplitCommand(optionString);			}
 		else if(commandName == "classify.otu")			{	command = new ClassifyOtuCommand(optionString);				}
@@ -583,6 +580,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
         else if(commandName == "biom.info")             {	command = new BiomInfoCommand(optionString);                }
         else if(commandName == "rename.file")           {	command = new RenameFileCommand(optionString);              }
         else if(commandName == "cluster.fit")           {	command = new ClusterFitCommand(optionString);              }
+        else if(commandName == "merge.otus")            {	command = new MergeOTUsCommand(optionString);               }
 		else											{	command = new NoCommand(optionString);						}
 
 		return command;
@@ -679,7 +677,6 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
 		else if(commandName == "make.group")			{	pipecommand = new MakeGroupCommand(optionString);				}
 		else if(commandName == "chop.seqs")				{	pipecommand = new ChopSeqsCommand(optionString);				}
 		else if(commandName == "clearcut")				{	pipecommand = new ClearcutCommand(optionString);				}
-		else if(commandName == "catchall")				{	pipecommand = new CatchAllCommand(optionString);				}
 		else if(commandName == "split.abund")			{	pipecommand = new SplitAbundCommand(optionString);				}
 		else if(commandName == "cluster.split")			{	pipecommand = new ClusterSplitCommand(optionString);			}
 		else if(commandName == "classify.otu")			{	pipecommand = new ClassifyOtuCommand(optionString);				}
@@ -759,7 +756,9 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
         else if(commandName == "biom.info")             {	pipecommand = new BiomInfoCommand(optionString);                }
         else if(commandName == "rename.file")           {	pipecommand = new RenameFileCommand(optionString);              }
         else if(commandName == "cluster.fit")           {	pipecommand = new ClusterFitCommand(optionString);              }
+        else if(commandName == "merge.otus")            {	pipecommand = new MergeOTUsCommand(optionString);               }
 		else											{	pipecommand = new NoCommand(optionString);						}
+        
 
 		return pipecommand;
 	}
@@ -840,7 +839,6 @@ Command* CommandFactory::getCommand(string commandName){
 		else if(commandName == "make.group")			{	shellcommand = new MakeGroupCommand();				}
 		else if(commandName == "chop.seqs")				{	shellcommand = new ChopSeqsCommand();				}
 		else if(commandName == "clearcut")				{	shellcommand = new ClearcutCommand();				}
-		else if(commandName == "catchall")				{	shellcommand = new CatchAllCommand();				}
 		else if(commandName == "split.abund")			{	shellcommand = new SplitAbundCommand();				}
 		else if(commandName == "cluster.split")			{	shellcommand = new ClusterSplitCommand();			}
 		else if(commandName == "classify.otu")			{	shellcommand = new ClassifyOtuCommand();			}
@@ -920,6 +918,7 @@ Command* CommandFactory::getCommand(string commandName){
         else if(commandName == "biom.info")             {	shellcommand = new BiomInfoCommand();               }
         else if(commandName == "rename.file")           {	shellcommand = new RenameFileCommand();             }
         else if(commandName == "cluster.fit")           {	shellcommand = new ClusterFitCommand();             }
+        else if(commandName == "merge.otus")            {	shellcommand = new MergeOTUsCommand();              }
 		else											{	shellcommand = new NoCommand();						}
 
 		return shellcommand;
@@ -1004,7 +1003,12 @@ void CommandFactory::printCommandsCategories(ostream& out) {
         }
 
         for (itCat = categories.begin(); itCat != categories.end(); itCat++) {
-            out << itCat->first << " commmands include: " << itCat->second << endl;
+            #if defined NON_WINDOWS
+                out << BOLDMAGENTA << endl << itCat->first << " commmands include: " << RESET << itCat->second << endl;
+            #else
+                out << endl << itCat->first << " commmands include: " << itCat->second << endl;
+            #endif
+            
         }
 
     }
