@@ -47,24 +47,26 @@ vector<string> AlignCommand::setParameters(){
 //**********************************************************************************************************************
 string AlignCommand::getHelpString(){	
 	try {
-		string helpString = "";
-		helpString += "The align.seqs command reads a file containing sequences and creates an alignment file and a report file.";
-		helpString += "The align.seqs command parameters are reference, fasta, search, ksize, align, match, mismatch, gapopen, gapextend and processors.";
-		helpString += "The reference and fasta parameters are required. You may leave fasta blank if you have a valid fasta file. You may enter multiple fasta files by separating their names with dashes. ie. fasta=abrecovery.fasta-amzon.fasta.";
-		helpString += "The search parameter allows you to specify the method to find most similar template.  Your options are: suffix, kmer and blast. The default is kmer.";
-		helpString += "The align parameter allows you to specify the alignment method to use.  Your options are: gotoh, needleman, blast and noalign. The default is needleman.";
-		helpString += "The ksize parameter allows you to specify the kmer size for finding most similar template to candidate.  The default is 8.";
-		helpString += "The match parameter allows you to specify the bonus for having the same base. The default is 1.0.";
-		helpString += "The mistmatch parameter allows you to specify the penalty for having different bases.  The default is -1.0.";
-		helpString += "The gapopen parameter allows you to specify the penalty for opening a gap in an alignment. The default is -5.0.";
-		helpString += "The gapextend parameter allows you to specify the penalty for extending a gap in an alignment.  The default is -2.0.";
-		helpString += "The flip parameter is used to specify whether or not you want mothur to try the reverse complement if a sequence falls below the threshold.  The default is false.";
-		helpString += "The threshold is used to specify a cutoff at which an alignment is deemed 'bad' and the reverse complement may be tried. The default threshold is 0.50, meaning 50% of the bases are removed in the alignment.";
-		helpString += "If the flip parameter is set to true the reverse complement of the sequence is aligned and the better alignment is reported. Default=t";
-		helpString += "The default for the threshold parameter is 0.50, meaning at least 50% of the bases must remain or the sequence is reported as potentially reversed.";
-		helpString += "The align.seqs command should be in the following format:";
-		helpString += "align.seqs(reference=yourTemplateFile, fasta=yourCandidateFile, align=yourAlignmentMethod, search=yourSearchmethod, ksize=yourKmerSize, match=yourMatchBonus, mismatch=yourMismatchpenalty, gapopen=yourGapopenPenalty, gapextend=yourGapExtendPenalty)";
-		helpString += "Example align.seqs(candidate=candidate.fasta, template=core.filtered, align=kmer, search=gotoh, ksize=8, match=2.0, mismatch=3.0, gapopen=-2.0, gapextend=-1.0)";
+		string helpString = "\n";
+		helpString += "The align.seqs command reads a file containing sequences and creates an alignment file and a report file.\n";
+		helpString += "The align.seqs command parameters are reference, fasta, search, ksize, align, match, mismatch, gapopen, gapextend and processors.\n";
+		helpString += "The reference and fasta parameters are required. You may leave fasta blank if you have a valid fasta file.\n";
+		helpString += "The search parameter allows you to specify the method to find most similar reference sequence.  Your options are: suffix, kmer and blast. The default is kmer.\n";
+		helpString += "The align parameter allows you to specify the alignment method to use.  Your options are: gotoh, needleman, blast and noalign. The default is needleman.\n";
+		helpString += "The ksize parameter allows you to specify the kmer size for finding most similar reference to a given sequence.  The default is 8.\n";
+		helpString += "The match parameter allows you to specify the bonus for having the same base. Default=1.0.\n";
+		helpString += "The mistmatch parameter allows you to specify the penalty for having different bases. Default=-1.0.\n";
+		helpString += "The gapopen parameter allows you to specify the penalty for opening a gap in an alignment. Default=-5.0.\n";
+		helpString += "The gapextend parameter allows you to specify the penalty for extending a gap in an alignment. Default=-2.0.\n";
+        helpString += "If the flip parameter is set to true the reverse complement of the sequence is aligned and the better alignment is reported.";
+		helpString += " By default, mothur will align the reverse compliment of your sequences when the alignment process removes more than 50% of the bases indicating the read may be flipped. This process assembles the best possible alignment, and downstream analysis will remove any poor quality reads remaining.\n";
+		helpString += "The threshold is used to specify a cutoff at which an alignment is deemed 'bad' and the reverse complement may be tried. The default threshold is 0.50, meaning 50% of the bases are removed in the alignment.\n";
+		helpString += "The align.seqs command should be in the following format: ";
+		helpString += "align.seqs(reference=yourTemplateFile, fasta=yourCandidateFile)\n";
+		helpString += "Example: align.seqs(candidate=candidate.fasta, template=silva.v4.fasta)\n";
+        
+        helpString += "\n\n";
+        helpString += getCommonQuestions();
 		
 		return helpString;
 	}
@@ -74,6 +76,25 @@ string AlignCommand::getHelpString(){
 	}
 }
 //**********************************************************************************************************************
+string AlignCommand::getCommonQuestions(){
+    try {
+        string commonQuestions = "";
+        commonQuestions += "\nCommon Issues: \n\n";
+        commonQuestions += "1. [ERROR]: template is not aligned, aborting. Mothur requires the reference file to be aligned to generate aligned sequences. You can download mothur's aligned silva references here, https://mothur.org/wiki/Silva_reference_files.\n";
+        commonQuestions += "2. [WARNING]: xxx of your sequences generated alignments that eliminated too many bases... By default, mothur will align the reverse compliment of your sequences when the alignment process removes more than 50% of the bases indicating the read may be flipped. This process assembles the best possible alignment, and downstream analysis will remove any poor quality reads remaining. \n";
+        
+        commonQuestions += "\nCommon Questions: \n\n";
+        commonQuestions += "1. How do I 'align' ITS sequences? \n\tYou really can't do an alignment because there isn't positional homology. You can use the pre.cluster and pairwise.seqs commands to generate a distance matrix from unaligned sequences. \n";
+        commonQuestions += "2. How do I create a custom reference for the region I am studying? \n\tYou can tailor your reference using this method: http://blog.mothur.org/2016/07/07/Customization-for-your-region/. \n";
+        
+        return commonQuestions;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "AlignCommand", "getCommonQuestions");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
 string AlignCommand::getOutputPattern(string type) {
     try {
         string pattern = "";
@@ -125,7 +146,7 @@ AlignCommand::AlignCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -144,9 +165,8 @@ AlignCommand::AlignCommand(string option)  {
 			else {
 				string path;
 
-				it = parameters.find("reference");
-
 				//user has given a template file
+                it = parameters.find("reference");
 				if(it != parameters.end()){ 
 					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
@@ -154,6 +174,10 @@ AlignCommand::AlignCommand(string option)  {
 				}
 			}
 
+            templateFileName = validParameter.validFile(parameters, "reference");
+            if (templateFileName == "not found") { m->mothurOut("[ERROR]: The reference parameter is a required for the align.seqs command, aborting.\n"); abort = true;
+            }else if (templateFileName == "not open") { abort = true; }
+            
 			candidateFileName = validParameter.valid(parameters, "fasta");
 			if (candidateFileName == "not found") { 
 				//if there is a current fasta file, use it
@@ -213,11 +237,6 @@ AlignCommand::AlignCommand(string option)  {
 			temp = validParameter.valid(parameters, "flip");			if (temp == "not found"){	temp = "t";				}
 			flip = util.isTrue(temp);
 			
-			//this has to go after save so that if the user sets save=t and provides no reference we abort
-			templateFileName = validParameter.validFile(parameters, "reference");
-			if (templateFileName == "not found") { m->mothurOut("[ERROR]: The reference parameter is a required for the align.seqs command, aborting.\n"); abort = true;
-			}else if (templateFileName == "not open") { abort = true; }	
-			
 			temp = validParameter.valid(parameters, "threshold");	if (temp == "not found"){	temp = "0.50";			}
 			util.mothurConvert(temp, threshold); 
 			
@@ -237,11 +256,7 @@ AlignCommand::AlignCommand(string option)  {
 }
 //**********************************************************************************************************************
 AlignCommand::~AlignCommand(){	
-
-	if (!abort) {
-		for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear();
-		delete templateDB;
-	}
+	if (!abort) { delete templateDB; }
 }
 //**********************************************************************************************************************
 
@@ -267,27 +282,7 @@ int AlignCommand::execute(){
             numFlipped.push_back(0); //numflipped because reverse was better
             numFlipped.push_back(0); //total number of sequences with over 50% of bases removed
 			
-			long long numFastaSeqs = 0;
-			for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear();
-
-			vector<unsigned long long> positions; 
-		#if defined NON_WINDOWS
-			positions = util.divideFile(candidateFileNames[s], processors);
-			for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(new linePair(positions[i], positions[(i+1)]));	}
-		#else
-            positions = util.setFilePosFasta(candidateFileNames[s], numFastaSeqs);
-            if (numFastaSeqs < processors) { processors = numFastaSeqs; m->mothurOut("Reducing processors to " + toString(numFastaSeqs) + ".\n");  }
-            
-            //figure out how many sequences you have to process
-            int numSeqsPerProcessor = numFastaSeqs / processors;
-            for (int i = 0; i < processors; i++) {
-                int startIndex =  i * numSeqsPerProcessor;
-                if(i == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - i * numSeqsPerProcessor; 	}
-                lines.push_back(new linePair(positions[startIndex], numSeqsPerProcessor));
-            }
-		#endif
-			
-            numFastaSeqs = createProcesses(alignFileName, reportFileName, accnosFileName, candidateFileNames[s], numFlipped);
+            long long numFastaSeqs = createProcesses(alignFileName, reportFileName, accnosFileName, candidateFileNames[s], numFlipped);
 				
 			if (m->getControl_pressed()) { util.mothurRemove(accnosFileName); util.mothurRemove(alignFileName); util.mothurRemove(reportFileName); outputTypes.clear();  return 0; }
 			
@@ -494,11 +489,11 @@ void alignDriver(alignStruct* params) {
 			#endif
 			
 			//report progress
-			if((count) % 100 == 0){	params->m->mothurOutJustToScreen(toString(count) + "\n"); 		}
+			if((count) % 1000 == 0){	params->m->mothurOutJustToScreen(toString(count) + "\n"); 		}
 			
 		}
 		//report progress
-		if((count) % 100 != 0){	params->m->mothurOutJustToScreen(toString(count) + "\n"); 		}
+		if((count) % 1000 != 0){	params->m->mothurOutJustToScreen(toString(count) + "\n"); 		}
         
         params->numSeqs += count;
         params->flippedResults[0] += numFlipped_0;
@@ -517,6 +512,26 @@ void alignDriver(alignStruct* params) {
 //void alignDriver(linePair* filePos, string alignFName, string reportFName, string accnosFName, string filename, vector<long long>& numFlipped,MothurOut* m, string align, float match, float misMatch, float gapOpen, float gapExtend, float threshold, bool flip, AlignmentDB* templateDB, string search, long long& count) {
 long long AlignCommand::createProcesses(string alignFileName, string reportFileName, string accnosFName, string filename, vector<long long>& numFlipped) {
 	try {
+        
+        vector<linePair> lines;
+        vector<unsigned long long> positions;
+#if defined NON_WINDOWS
+        positions = util.divideFile(filename, processors);
+        for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(linePair(positions[i], positions[(i+1)]));	}
+#else
+        long long numFastaSeqs = 0;
+        positions = util.setFilePosFasta(filename, numFastaSeqs);
+        if (numFastaSeqs < processors) { processors = numFastaSeqs; m->mothurOut("Reducing processors to " + toString(numFastaSeqs) + ".\n");  }
+        
+        //figure out how many sequences you have to process
+        int numSeqsPerProcessor = numFastaSeqs / processors;
+        for (int i = 0; i < processors; i++) {
+            int startIndex =  i * numSeqsPerProcessor;
+            if(i == (processors - 1)){	numSeqsPerProcessor = numFastaSeqs - i * numSeqsPerProcessor; 	}
+            lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
+        }
+#endif
+
         //create array of worker threads
         vector<thread*> workerThreads;
         vector<alignStruct*> data;
@@ -541,7 +556,7 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
             OutputWriter* threadAccnosWriter = new OutputWriter(synchronizedOutputAccnosFile);
 
             
-            alignStruct* dataBundle = new alignStruct(*lines[i+1], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
+            alignStruct* dataBundle = new alignStruct(lines[i+1], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
                                                         align, match, misMatch, gapOpen, gapExtend, threshold, flip, templateDB, search);
             data.push_back(dataBundle);
 
@@ -552,7 +567,7 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
         OutputWriter* threadReportWriter = new OutputWriter(synchronizedOutputReportFile);
         OutputWriter* threadAccnosWriter = new OutputWriter(synchronizedOutputAccnosFile);
         
-        alignStruct* dataBundle = new alignStruct(*lines[0], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
+        alignStruct* dataBundle = new alignStruct(lines[0], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
                                                   align, match, misMatch, gapOpen, gapExtend, threshold, flip, templateDB, search);
         alignDriver(dataBundle);
         numFlipped[0] = dataBundle->flippedResults[0];
@@ -572,6 +587,7 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
             delete data[i];
             delete workerThreads[i];
         }
+        synchronizedOutputAlignFile->close(); synchronizedOutputReportFile->close(); synchronizedOutputAccnosFile->close();
         delete threadAlignWriter; delete threadAccnosWriter; delete threadReportWriter;
         delete dataBundle;
         
