@@ -17,6 +17,7 @@ vector<string> BiomInfoCommand::setParameters(){
         CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
         CommandParameter prelabund("relabund", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(prelabund);
         CommandParameter pbasis("basis", "Multiple", "otu-sequence", "otu", "", "", "","",false,false); parameters.push_back(pbasis);
+        CommandParameter pformat("format", "Multiple", "hdf5-simple", "hdf5", "", "", "","",false,false, true); parameters.push_back(pformat);
         CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter poutput("output", "Multiple", "simple-detail", "detail", "", "", "","",false,false, true); parameters.push_back(poutput);
         CommandParameter pprintlevel("printlevel", "Number", "", "-1", "", "", "","",false,false); parameters.push_back(pprintlevel);
@@ -43,6 +44,7 @@ string BiomInfoCommand::getHelpString(){
         helpString += "The basis parameter allows you indicate what you want the summary file to represent, options are otu and sequence. Default is otu.\n";
         helpString += "The output parameter allows you to specify format of your summary file. Options are simple and detail. The default is detail.\n";
         helpString += "The printlevel parameter allows you to specify taxlevel of your summary file to print to. Options are 1 to the maz level in the file.  The default is -1, meaning max level.  If you select a level greater than the level your sequences classify to, mothur will print to the level your max level. \n";
+        helpString += "The format parameter allows you indicate type of biom file you have. Options hdf5 or classic. Default is hdf5.\n";
         helpString += "For example consider the following basis=sequence could give Clostridiales	3	105, where 105 is the total number of sequences whose otu classified to Clostridiales.\n";
         helpString += "Now for basis=otu could give Clostridiales	3	7, where 7 is the number of otus that classified to Clostridiales.\n";
         helpString += "The biom.info command should be in the following format: biom.info(biom=test.biom, label=0.03).\n";
@@ -109,7 +111,7 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
             
             //check to make sure all parameters are valid for command
             for (it = parameters.begin(); it != parameters.end(); it++) {
-                if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
             }
             
             //if the user changes the input directory command factory will send this info to us in the output parameter
@@ -156,7 +158,20 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
             basis = validParameter.valid(parameters, "basis");
             if (basis == "not found") { basis = "otu"; }
             
-            if ((basis != "otu") && (basis != "sequence")) { m->mothurOut("Invalid option for basis. basis options are otu and sequence, using otu."); m->mothurOutEndLine(); }
+            if ((basis != "otu") && (basis != "sequence")) { m->mothurOut("Invalid option for basis. basis options are otu and sequence, using otu.\n"); }
+            
+            format = validParameter.valid(parameters, "format");
+            if (format == "not found") { format = "classic"; }
+            
+            if ((format != "hdf5") && (format != "classic")) { m->mothurOut("Invalid option for format. format options are hdf5 and classic, using hdf5.\n"); }
+            
+            if (format == "hdf5") {
+                #ifdef USE_HDF5
+                //do nothing we have the api
+                #else
+                    m->mothurOut("[ERROR]: To read HDF5 biom files, you must have the API installed, quitting.\n"); abort=true;
+                #endif
+            }
         }
         
     }
@@ -174,7 +189,8 @@ int BiomInfoCommand::execute(){
         
         long start = time(NULL);
         
-        createFilesFromBiom();
+        if (format == "hdf5")   { extractFilesFromHDF5();   }
+        else                    { createFilesFromBiom();    }
         
         m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(NULL) - start) + " create mothur files from your biom file.\n");	m->mothurOutEndLine();
         
@@ -210,6 +226,386 @@ int BiomInfoCommand::execute(){
         exit(1);
     }
 }
+#ifdef USE_HDF5
+//**********************************************************************************************************************
+//Process attribute of group or dataset
+void BiomInfoCommand::processAttributes(H5::Group& groupID, set<string>& requiredAttributes) {
+    try {
+        
+        for (set<string>::iterator it = requiredAttributes.begin(); it != requiredAttributes.end(); it++) {
+            
+            
+            H5::Attribute attribute(groupID.openAttribute(*it));
+            H5std_string attributeName; attribute.getName(attributeName);
+            H5::DataType  attributeType(attribute.getDataType());
+            H5::DataSpace attDataSpace = attribute.getSpace();
+            
+            int rank = attDataSpace.getSimpleExtentNdims(); //number of dimensions
+            hsize_t dims[rank]; attDataSpace.getSimpleExtentDims(dims); //size of each dimension
+            
+            // Read the Attribute Data. Depends on the kind of data
+            if (attributeType.getClass() == H5T_STRING) {
+                if (rank == 0) {
+                    H5std_string biomTableId;
+                    attribute.read(attributeType, biomTableId);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: " + attributeName + " = " + biomTableId + "\n");  }
+                }
+            }else if (attributeType.getClass() == H5T_INTEGER) {
+                if (attDataSpace.isSimple()) {
+                    
+                    if (rank == 0) {
+                        hsize_t data = 0;
+                        attribute.read(attributeType, &data);
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: " + attributeName + " = " + toString(data) + "\n");  }
+                        if (attributeName == "nnz") { nnz = data; }
+                    }else if (rank == 1) {
+                        hsize_t data[dims[0]];
+                        attribute.read(attributeType, data);
+                        if (m->getDebug()) { m->mothurOut("[DEBUG]: " + attributeName + " = "); }
+                        for (int i = 0; i < dims[0]; i++) {
+                            if (m->getDebug()) { m->mothurOut(toString(data[i]) + "\t"); }
+                            if (attributeName == "nnz") { nnz = data[i]; }
+                        }  if (m->getDebug()) { m->mothurOutEndLine(); }
+                    }
+                }
+                
+            }else if (attributeType.getClass() == H5T_FLOAT) {
+                m->mothurOut("[WARNING]: the shared file only uses integers, any float values will be rounded down to the nearest integer.\n");
+                if (rank == 0) {
+                    hsize_t data = 0;
+                    attribute.read(attributeType, &data);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: " + attributeName + " = " + toString(data) + "\n");  }
+                }else if (rank == 1) {
+                    hsize_t data[dims[0]];
+                    attribute.read(attributeType, data);
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: " + attributeName + " = "); }
+                    for (int i = 0; i < dims[0]; i++) {
+                        if (m->getDebug()) { m->mothurOut(toString(data[i]) + "\t"); }
+                    } if (m->getDebug()) { m->mothurOutEndLine(); }
+                }
+   
+            }else { m->mothurOut("[ERROR]: Unexpected datatype class, quitting.\n"); m->setControl_pressed(true);  }
+            
+            attribute.close();
+        }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "BiomInfoCommand", "processAttributes");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+//check to make sure required groups are present
+void BiomInfoCommand::checkGroups( H5::H5File& file, map<string, vector<string> >& requiredGroups) {
+    try {
+       
+        for (map<string, vector<string> >::iterator it = requiredGroups.begin(); it != requiredGroups.end(); it++) {
+            
+            H5std_string groupName = it->first;
+            vector<string> datasetNames = it->second;
+            H5::Group group(file.openGroup(groupName));
+            
+            for (int h = 0; h < datasetNames.size(); h++) {
+                string datasetName = datasetNames[h];
+                int numObjects = group.getNumObjs();
+                
+                if (numObjects != 0) {
+                    H5::DataSet dataset = group.openDataSet(datasetName);
+                    H5::DataType  dataType(dataset.getDataType());
+                    H5::DataSpace dataSpace = dataset.getSpace();
+                    
+                    int rank = dataSpace.getSimpleExtentNdims(); //number of dimensions
+                    hsize_t dims[rank]; dataSpace.getSimpleExtentDims(dims); //size of each dimension
+                    
+                    if (dataset.getTypeClass() == H5T_STRING) {
+                        if (rank == 1) {
+                            char **data = new char*[dims[0]];
+                            H5::StrType str_type(H5::PredType::C_S1, H5T_VARIABLE);
+                            dataset.read((void*)data, str_type);
+                            
+                            if (m->getDebug()) { m->mothurOut("[DEBUG]: " + datasetName + " = "); }
+                            
+                            for (int i = 0; i < dims[0]; i++) {
+                                if (m->getDebug()) { m->mothurOut(toString(data[i]) + "\t"); }
+                                
+                                if (groupName == "observation/") {
+                                    otuNames.push_back(data[i]);
+                                }else if (groupName == "sample/") {
+                                    sampleNames.push_back(data[i]);
+                                }else if (groupName == "observation/metadata") {
+                                    if (datasetName == "taxonomy") { taxonomy.push_back(data[i]); }
+                                }
+                                delete[] data[i];
+                            }  if (m->getDebug()) { m->mothurOutEndLine(); }
+                            delete[] data;
+                        }else if (rank == 2) {
+                            
+                            char **data = new char*[dims[0]*dims[1]];
+
+                            H5::StrType str_type(H5::PredType::C_S1, H5T_VARIABLE);
+                            dataset.read((void*)data, str_type);
+                            
+                            string otuTaxonomy = ""; int count = 0;
+                            for (int i = 0; i < dims[0]*dims[1]; i++) {
+                                
+                                if (groupName == "observation/metadata") {
+                                    if (datasetName == "taxonomy") {  otuTaxonomy += data[i];  otuTaxonomy += ";";  count++; }
+                                }
+                                
+                                if (count == dims[1]) {
+                                    if (m->getDebug()) { m->mothurOut("[DEBUG]: " + toString(otuTaxonomy) + "\n"); }
+                                    taxonomy.push_back(otuTaxonomy);
+                                    count = 0; otuTaxonomy = "";
+                                }
+                            }
+                        }
+                    }else if (dataset.getTypeClass() == H5T_INTEGER) {
+                        
+                        if (rank == 1) {
+                            int* data = new int[dims[0]];
+                            H5::DataSpace data_mspace(rank, dims);
+                            dataset.read(data, H5::PredType::NATIVE_INT, data_mspace, dataSpace);
+                            
+                            if (m->getDebug()) { m->mothurOut("[DEBUG]: " + datasetName + " = "); }
+                            for (int i = 0; i < dims[0]; i++) {
+                                if (m->getDebug()) { m->mothurOut(toString(data[i]) + "\t"); }
+                                
+                                if (groupName == "observation/matrix/") {
+                                    if (datasetName == "data") { otudata.push_back(data[i]); }
+                                    else if (datasetName == "indices") { indices.push_back(data[i]); }
+                                    else if (datasetName == "indptr") { indptr.push_back(data[i]); }
+                                }
+                            } if (m->getDebug()) { m->mothurOutEndLine(); }
+                            delete[] data;
+                        }
+                        
+                    }else if (dataset.getTypeClass() == H5T_FLOAT) {
+                        
+                        if (rank == 1) {
+                            float* data = new float[dims[0]];
+                            H5::DataSpace data_mspace(rank, dims);
+                            dataset.read(data, H5::PredType::NATIVE_FLOAT, data_mspace, dataSpace);
+                            
+                            if (m->getDebug()) { m->mothurOut("[DEBUG]: " + datasetName + " = "); }
+                            for (int i = 0; i < dims[0]; i++) {
+                                if (m->getDebug()) { m->mothurOut(toString(data[i]) + "\t"); }
+                                
+                                if (groupName == "observation/matrix/") {
+                                    if (datasetName == "data") { otudata.push_back((int)data[i]); }
+                                    else if (datasetName == "indices") { indices.push_back((int)data[i]); }
+                                    else if (datasetName == "indptr") { indptr.push_back((int)data[i]); }
+                                }
+                            }  if (m->getDebug()) { m->mothurOutEndLine(); }
+                            delete[] data;
+                        }
+                    }else { m->mothurOut("[ERROR]: Unexpected datatype class, quitting.\n"); m->setControl_pressed(true);  }
+                    
+                    dataset.close();
+                }
+            }
+            group.close();
+        }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "BiomInfoCommand", "checkGroups");
+        exit(1);
+    }
+}
+#endif
+//**********************************************************************************************************************
+int BiomInfoCommand::extractFilesFromHDF5() {
+    try {
+        //getting output filename
+        string filename = biomfile;
+        if (outputDir == "") { outputDir += util.hasPath(filename); }
+        
+        map<string, string> variables;
+        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+        variables["[tag]"] = label;
+        string sharedFilename = getOutputFileName("shared",variables);
+        string taxFilename = getOutputFileName("constaxonomy",variables);
+        variables["[tag2]"] = "cons";
+        string taxSumFilename = getOutputFileName("taxsummary",variables);
+        
+        nnz = 0;
+        set<string> requiredTopLevelAttrib;
+        map<string, vector<string> > requiredOTUDatasets;
+        map<string, vector<string> > requiredSampleDatasets;
+        map<string, vector<string> > optionalDatasets;
+
+        //set required fields
+        requiredTopLevelAttrib.insert("id"); requiredTopLevelAttrib.insert("type"); requiredTopLevelAttrib.insert("format-url");
+        requiredTopLevelAttrib.insert("format-version"); requiredTopLevelAttrib.insert("generated-by"); requiredTopLevelAttrib.insert("creation-date");
+        requiredTopLevelAttrib.insert("shape"); requiredTopLevelAttrib.insert("nnz");
+        
+        //set required datasets - groupname -> datasetname
+        vector<string> datasets; datasets.push_back("ids");
+        requiredOTUDatasets["observation/"] = datasets; //otuLabels - "GG_OTU_1", "GG_OTU_2", "GG_OTU_3", "GG_OTU_4", "GG_OTU_5"
+        datasets.clear();
+        datasets.push_back("data"); //otu abundances for each non zero abundnace entry - 1, 5, 1, 2, 3, 1, 1, 4, 2, 2, 1, 1, 1, 1, 1
+        datasets.push_back("indices"); //index of group - maps into samples/ids  2, 0, 1, 3, 4, 5, 2, 3, 5, 0, 1, 2, 5, 1, 2
+        datasets.push_back("indptr"); //maps non zero abundance to OTU - 0, 1, 6, 9, 13, 15 - 0 start of OTU1s indexes, 1 start of OTU2s indexes, ... 15 start of OTU5s indexes
+        requiredOTUDatasets["observation/matrix/"] = datasets;
+        
+        datasets.clear(); datasets.push_back("ids"); //group names - "Sample1", "Sample2", "Sample3", "Sample4", "Sample5", "Sample6"
+        requiredSampleDatasets["sample/"] = datasets;
+        datasets.clear(); datasets.push_back("taxonomy"); //optional datasets to look for - taxonomy info - otu classifications
+        optionalDatasets["observation/metadata"] = datasets;
+
+        /*
+         label group numOtus GG_OTU_1  GG_OTU_2  GG_OTU_3  GG_OTU_4  GG_OTU_5
+         userLabel  Sample1     0           5       0           2       0
+         userLabel  Sample2     0           1       0           2       1
+         userLabel  Sample3     1           0       1           1       1
+         userLabel  Sample4     0           2       4           0       0
+         userLabel  Sample5     0           3       0           0       0
+         userLabel  Sample6     0           1       2           1       0
+         */
+        
+        #ifdef USE_HDF5
+        H5::H5File file( filename.c_str(), H5F_ACC_RDONLY );
+        H5::Group     what(file.openGroup( "/" ));
+      
+        processAttributes(what, requiredTopLevelAttrib); if (m->getControl_pressed()) { return 0; }
+
+        try {
+            
+            checkGroups(file, requiredOTUDatasets); if (m->getControl_pressed()) { return 0; }
+            
+        }catch(H5::Exception& e){ //do nothing taxonomy info does not exist
+            m->mothurOut("[ERROR]: Missing required groups or datasets, aborting. Required datasets include: \n");
+            for (map<string, vector< string> >::iterator it = requiredOTUDatasets.begin(); it != requiredOTUDatasets.end(); it++) {
+                for (int i = 0; i < (it->second).size(); i++) { m->mothurOut(it->first + '\t' + it->second[i] + '\n'); }
+            }
+            m->mothurOutEndLine(); m->setControl_pressed(true);
+        }
+        
+        try {
+            
+            checkGroups(file, requiredSampleDatasets); if (m->getControl_pressed()) { return 0; }
+            
+        }catch(H5::Exception& e){ //do nothing taxonomy info does not exist
+            m->mothurOut("[ERROR]: Missing required groups or datasets, aborting. Required datasets include: \n");
+            for (map<string, vector< string> >::iterator it = requiredOTUDatasets.begin(); it != requiredOTUDatasets.end(); it++) {
+                for (int i = 0; i < (it->second).size(); i++) { m->mothurOut(it->first + '\t' + it->second[i] + '\n'); }
+            }
+            m->mothurOutEndLine(); m->setControl_pressed(true);
+        }
+        
+        bool hasTaxonomy = false;
+        try {
+            
+            checkGroups(file, optionalDatasets); if (m->getControl_pressed()) { return 0; }
+            
+            if (taxonomy.size() == otuNames.size()) { hasTaxonomy = true; }
+            
+        }catch(H5::Exception& e){ //do nothing taxonomy info does not exist
+            m->mothurOut("\nIgnore HDF5 errors, mothur was checking for OTU taxonomies and your file does not contain them. They are not required, continuing.\n");
+            hasTaxonomy = false;
+        }
+
+        
+        bool error = false;
+        if (nnz != otudata.size()) { error = true; }
+        
+        //create shared file
+        sort(sampleNames.begin(), sampleNames.end());
+        
+        //create empty sharedrabundvectors so we can add otus below
+        SharedRAbundVectors lookup;
+        for (int i = 0; i < sampleNames.size(); i++) {
+            SharedRAbundVector* temp = new SharedRAbundVector();
+            temp->setGroup(sampleNames[i]);
+            lookup.push_back(temp);
+        }
+        
+        lookup.setLabels(label);
+        
+        ofstream outTax;
+        if (hasTaxonomy) {
+            outputNames.push_back(taxFilename); outputTypes["constaxonomy"].push_back(taxFilename);
+            util.openOutputFile(taxFilename, outTax);
+            outTax << "OTU\tSize\tTaxonomy\n";
+        }
+        
+        //for each otu
+        int count = 0;
+        for (int h = 0; h < indptr.size()-1; h++) {
+            int otuStart = indptr[h];
+            int otuEnd = indptr[h+1];
+            
+            vector<int> otuAbunds; otuAbunds.resize(sampleNames.size(), 0); //initialze otus sample abundances to 0 - only non zero abunds are recorded
+            
+            for (int i = otuStart; i < otuEnd; i++) {
+                otuAbunds[indices[i]] = otudata[count]; count++;
+            }
+            
+            lookup.push_back(otuAbunds, otuNames[h]);
+        }
+        
+        ofstream out; util.openOutputFile(sharedFilename, out);
+        m->mothurOut("\n"+lookup.getLabel()+"\n"); bool printHeaders = true;
+        lookup.print(out, printHeaders);
+        out.close();
+        outputNames.push_back(sharedFilename); outputTypes["shared"].push_back(sharedFilename);
+        
+        if (hasTaxonomy) {
+            
+            CountTable ct; for (int j = 0; j < sampleNames.size(); j++) {  ct.addGroup(sampleNames[j]); }
+            int numBins = lookup.getNumBins();
+            
+            for (int i = 0; i < numBins; i++) {
+                vector<int> abunds;
+                for (int j = 0; j < lookup.size(); j++) {
+                    if (m->getControl_pressed()) { break; }
+                    int abund = lookup.get(i, sampleNames[j]);
+                    if (basis == "otu") { if (abund > 0) { abund = 1;  } } //count presence in otu
+                    abunds.push_back(abund);
+                }
+                ct.push_back(otuNames[i], abunds);
+            }
+            
+            PhyloSummary taxaSum(&ct, relabund, printlevel);
+            
+            for (int i = 0; i < lookup.getNumBins(); i++) {
+                if (m->getControl_pressed()) { break; }
+                
+                int total = 0;
+                map<string, bool> containsGroup;
+                for (int j = 0; j < lookup.size(); j++) {
+                    int abund = lookup.get(i, sampleNames[j]);
+                    total += abund;
+                    containsGroup[sampleNames[j]] = abund;
+                }
+                
+                string newTax = util.addUnclassifieds(taxonomy[i], maxLevel, false);
+                outTax << otuNames[i] << '\t' << total << '\t' << newTax << endl;
+                
+                if (basis == "sequence") {
+                    taxaSum.addSeqToTree(otuNames[i], newTax);
+                }else {
+                    taxaSum.addSeqToTree(newTax, containsGroup); //add otu
+                }
+            }
+            outTax.close();
+            
+            //write taxonomy summary file
+            outputNames.push_back(taxSumFilename); outputTypes["taxsummary"].push_back(taxSumFilename);
+            ofstream outTaxSum;
+            util.openOutputFile(taxSumFilename, outTaxSum);
+            taxaSum.print(outTaxSum, output);
+            outTaxSum.close();
+        }
+
+        #endif
+        
+        return 0;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "BiomInfoCommand", "extractFilesFromHDF5");
+        exit(1);
+    }
+}
 //**********************************************************************************************************************
 int BiomInfoCommand::createFilesFromBiom() {
     try {
@@ -254,6 +650,7 @@ int BiomInfoCommand::createFilesFromBiom() {
         bool atComma = false;
         string line = "";
         string matrixElementType = "";
+        bool printHeaders = true;
         
         while (!in.eof()) { //split file by tags, so each "line" will have something like "id":"/Users/SarahsWork/Desktop/release/final.tx.1.subsample.1.pick.shared-1"
             if (m->getControl_pressed()) { break; }
@@ -440,8 +837,8 @@ int BiomInfoCommand::createFilesFromBiom() {
             string thisLine = it->second;
             SharedRAbundVectors* lookup = readData(matrixFormat, thisLine, matrixElementType, groupNames, otuNames.size());
             lookup->setOTUNames(otuNames);
-            m->mothurOutEndLine(); m->mothurOut(lookup->getLabel()+"\n"); 
-            lookup->print(out);
+            m->mothurOut("\n"+lookup->getLabel()+"\n");
+            lookup->print(out, printHeaders);
             
             if (conTaxonomy.size() != 0) {
                 //sanity check
@@ -456,24 +853,24 @@ int BiomInfoCommand::createFilesFromBiom() {
                     util.openOutputFile(taxFilename, outTax);
                     outTax << "OTU\tSize\tTaxonomy\n";
                     
-                    CountTable* ct = NULL;
-                    if (basis == "otu") {
-                        ct = new CountTable();
-                        vector<string> groupNames = lookup->getNamesGroups();
-                        for (int j = 0; j < groupNames.size(); j++) {  ct->addGroup(groupNames[j]); }
+                    CountTable ct;
+                    vector<string> groupNames = lookup->getNamesGroups();
+                    for (int j = 0; j < groupNames.size(); j++) {  ct.addGroup(groupNames[j]); }
                         
-                        int numBins = lookup->getNumBins();
-                        for (int i = 0; i < numBins; i++) {
-                            vector<int> abunds;
-                            for (int j = 0; j < lookup->size(); j++) {
-                                if (m->getControl_pressed()) { break; }
-                                abunds.push_back(lookup->get(i, groupNames[j]));
-                            }
-                            ct->push_back(otuNames[i], abunds);
+                    int numBins = lookup->getNumBins();
+                    
+                    for (int i = 0; i < numBins; i++) {
+                        vector<int> abunds;
+                        for (int j = 0; j < lookup->size(); j++) {
+                            if (m->getControl_pressed()) { break; }
+                            int abund = lookup->get(i, groupNames[j]);
+                            if (basis == "otu") { if (abund > 0) { abund = 1;  } } //count presence in otu
+                            abunds.push_back(abund);
                         }
+                        ct.push_back(otuNames[i], abunds);
                     }
                     
-                    PhyloSummary taxaSum(ct, relabund, printlevel);
+                    PhyloSummary taxaSum(&ct, relabund, printlevel);
                     
                     for (int i = 0; i < lookup->getNumBins(); i++) {
                         if (m->getControl_pressed()) { break; }
@@ -490,7 +887,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                         outTax << otuNames[i] << '\t' << total << '\t' << newTax << endl;
                         
                         if (basis == "sequence") {
-                            for (int k = 0; k < total; k++) { taxaSum.addSeqToTree(otuNames[i], newTax); } //one for each sequence in the otu
+                            taxaSum.addSeqToTree(otuNames[i], newTax);
                         }else {
                             taxaSum.addSeqToTree(newTax, containsGroup); //add otu
                         }
@@ -507,9 +904,6 @@ int BiomInfoCommand::createFilesFromBiom() {
                     util.openOutputFile(taxSumFilename, outTaxSum);
                     taxaSum.print(outTaxSum, output);
                     outTaxSum.close();
-                    
-                    if (ct != NULL) { delete ct; }
-                   
                 }
             }
             
