@@ -94,7 +94,7 @@ string ChimeraVsearchCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ChimeraVsearchCommand::ChimeraVsearchCommand(){
+ChimeraVsearchCommand::ChimeraVsearchCommand() : Command(){
     try {
         abort = true; calledHelp = true;
         setParameters();
@@ -110,7 +110,7 @@ ChimeraVsearchCommand::ChimeraVsearchCommand(){
     }
 }
 //***************************************************************************************************************
-ChimeraVsearchCommand::ChimeraVsearchCommand(string option)  {
+ChimeraVsearchCommand::ChimeraVsearchCommand(string option) : Command() {
     try {
         abort = false; calledHelp = false; hasName=false; hasCount=false;
         
@@ -129,7 +129,7 @@ ChimeraVsearchCommand::ChimeraVsearchCommand(string option)  {
             
             //check to make sure all parameters are valid for command
             for (it = parameters.begin(); it != parameters.end(); it++) {
-                if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
             }
             
             vector<string> tempOutNames;
@@ -160,7 +160,7 @@ ChimeraVsearchCommand::ChimeraVsearchCommand(string option)  {
                         fastaFileNames[i] = current->getFastaFile();
                         if (fastaFileNames[i] != "") {  m->mothurOut("Using " + fastaFileNames[i] + " as input file for the fasta parameter where you had given current."); m->mothurOutEndLine(); }
                         else {
-                            m->mothurOut("You have no current fastafile, ignoring current."); m->mothurOutEndLine(); ignore=true;
+                            m->mothurOut("You have no current fastafile, ignoring current.\n"); ignore=true;
                             //erase from file list
                             fastaFileNames.erase(fastaFileNames.begin()+i);
                             i--;
@@ -335,19 +335,20 @@ ChimeraVsearchCommand::ChimeraVsearchCommand(string option)  {
             if (hasName && (templatefile != "self")) { m->mothurOut("You have provided a namefile and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting."); m->mothurOutEndLine(); abort=true; }
             if (hasCount && (templatefile != "self")) { m->mothurOut("You have provided a countfile and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting."); m->mothurOutEndLine(); abort=true; }
             if (hasGroup && (templatefile != "self")) { m->mothurOut("You have provided a group file and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting."); m->mothurOutEndLine(); abort=true; }
-            
+
             //look for uchime exe
-            path = current->getProgramPath();         
+            path = current->getProgramPath();
+
             string vsearchCommand;
 #if defined NON_WINDOWS
             vsearchCommand = path + "vsearch";	//	format the database, -o option gives us the ability
             if (m->getDebug()) {
                 m->mothurOut("[DEBUG]: vsearch location using \"which vsearch\" = ");
-                Command* newCommand = new SystemCommand("which vsearch"); m->mothurOutEndLine();
+                Command* newCommand = new SystemCommand("which vsearch\n");
                 newCommand->execute();
                 delete newCommand;
                 m->mothurOut("[DEBUG]: Mothur's location using \"which mothur\" = ");
-                newCommand = new SystemCommand("which mothur"); m->mothurOutEndLine();
+                newCommand = new SystemCommand("which mothur\n");
                 newCommand->execute();
                 delete newCommand;
             }
@@ -369,7 +370,7 @@ ChimeraVsearchCommand::ChimeraVsearchCommand(string option)  {
                 uLocation += programName;
                 ableToOpen = util.openInputFile(uLocation, in2, "no error"); in2.close();
                 
-                if(!ableToOpen) { m->mothurOut("[ERROR]: " + uLocation + " file does not exist. mothur requires the vsearch executable."); m->mothurOutEndLine(); abort = true; }
+                if(!ableToOpen) { m->mothurOut("[ERROR]: " + uLocation + " file does not exist. mothur requires the vsearch executable.\n");  abort = true; }
                 else {  m->mothurOut("Found vsearch in your path, using " + uLocation + "\n");vsearchLocation = uLocation; }
             }else {  vsearchLocation = vsearchCommand; }
             
@@ -422,7 +423,7 @@ int ChimeraVsearchCommand::execute(){
             //setup fasta file if denovo and no groups
             if ((templatefile == "self") && (!hasGroup)) { //you want to run uchime with a template=self and no groups
                 
-                if (processors != 1) { m->mothurOut("When using template=self, mothur can only use 1 processor, continuing."); m->mothurOutEndLine(); processors = 1; }
+                if (processors != 1) { m->mothurOut("When using template=self, mothur can only use 1 processor, continuing.\n"); processors = 1; }
                 if (nameFileNames.size() != 0) { //you provided a namefile and we don't need to create one
                     nameFile = nameFileNames[s];
                 }else { nameFile = getNamesFile(fastaFileNames[s]); }
@@ -508,12 +509,16 @@ int ChimeraVsearchCommand::execute(){
                     if (hasCount) {
                         set<string> doNotRemove;
                         CountTable c; c.readTable(newCountFile, true, true);
+                        c.eliminateZeroSeqs();
                         vector<string> namesInTable = c.getNamesOfSeqs();
-                        for (int i = 0; i < namesInTable.size(); i++) {
-                            int temp = c.getNumSeqs(namesInTable[i]);
-                            if (temp == 0) {  c.remove(namesInTable[i]);  }
-                            else { doNotRemove.insert((namesInTable[i])); }
-                        }
+                        for (int i = 0; i < namesInTable.size(); i++) { doNotRemove.insert(namesInTable[i]); }
+                        /*vector<string> namesInTable = c.getNamesOfSeqs();
+                         for (int i = 0; i < namesInTable.size(); i++) {
+                         int temp = c.getNumSeqs(namesInTable[i]);
+                         if (temp == 0) {  c.remove(namesInTable[i]);  }
+                         else { doNotRemove.insert((namesInTable[i])); }
+                         }*/
+
                         //remove names we want to keep from accnos file.
                         set<string> accnosNames = util.readAccnos(accnosFileName);
                         ofstream out2;
@@ -1024,8 +1029,9 @@ int ChimeraVsearchCommand::driver(string outputFName, string filename, string ac
         alns = "\"" + alns + "\"";
         
         vector<char*> cPara;
-        
-        string vsearchCommand = vsearchLocation;
+        string vsearchCommand = "";
+
+        vsearchCommand += vsearchLocation;
         vsearchCommand = "\"" + vsearchCommand + "\" ";
         
         char* tempVsearch;
@@ -1181,7 +1187,6 @@ int ChimeraVsearchCommand::driver(string outputFName, string filename, string ac
 #endif
         
         if (m->getDebug()) { m->mothurOut("[DEBUG]: vsearch command = " + commandString + ".\n"); }
-        //cout << "commandString = " << commandString << endl;
         
         system(commandString.c_str());
         
@@ -1224,9 +1229,7 @@ int ChimeraVsearchCommand::driver(string outputFName, string filename, string ac
         out.close();
         
         util.mothurRemove(outputFNamec);
-        
-        //if (templatefile != "self") {  util.mothurRemove(filename); }
-        
+                
         return 0;
     }
     catch(exception& e) {
