@@ -142,7 +142,7 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -641,7 +641,7 @@ void driverClassifier(classifyData* params){
                 
                 if (params->m->getControl_pressed()) { delete candidateSeq; break; }
                 
-                if (taxonomy == "unknown;") { params->m->mothurOut("[WARNING]: " + candidateSeq->getName() + " could not be classified. You can use the remove.lineage command with taxon=unknown; to remove such sequences."); params->m->mothurOutEndLine(); }
+                if (taxonomy == "unknown;") { params->m->mothurOut("[WARNING]: " + candidateSeq->getName() + " could not be classified. You can use the remove.lineage command with taxon=unknown; to remove such sequences.\n");  }
                 
                 //output confidence scores or not
                 if (params->probs)  { taxBuffer += candidateSeq->getName() + '\t' + taxonomy + '\n';    }
@@ -705,9 +705,7 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
         positions = util.divideFile(filename, processors);
         for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(new linePair(positions[i], positions[(i+1)]));	}
 #else
-        if (processors == 1) {
-            lines.push_back(new linePair(0, 1000));
-        }else {
+        
             positions = util.setFilePosFasta(filename, num);
             if (num < processors) { processors = num; }
             
@@ -718,7 +716,7 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
                 if(i == (processors - 1)){	numSeqsPerProcessor = num - i * numSeqsPerProcessor; 	}
                 lines.push_back(new linePair(positions[startIndex], numSeqsPerProcessor));
             }
-        }
+       
 #endif
         auto synchronizedAccnosFile = std::make_shared<SynchronizedOutputFile>(accnos);
         auto synchronizedTaxFile = std::make_shared<SynchronizedOutputFile>(taxFileName);
@@ -755,6 +753,7 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
             delete data[i];
             delete workerThreads[i];
         }
+        synchronizedTaxTFile->close(); synchronizedTaxFile->close(); synchronizedAccnosFile->close();
         delete threadTaxWriter; delete threadTaxTWriter; delete threadAccnosWriter;
         delete dataBundle;
         time(&end);
