@@ -10,7 +10,8 @@
 
 //**********************************************************************************************************************
 vector<string> FilterSharedCommand::setParameters(){	
-	try {		
+	try {
+        CommandParameter paccnos("accnos", "InputTypes", "", "", "none", "none", "none","",false,false); parameters.push_back(paccnos);
 		CommandParameter pshared("shared", "InputTypes", "", "", "none", "none", "none","shared",false,true,true); parameters.push_back(pshared);
 		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
 		CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
@@ -42,6 +43,7 @@ string FilterSharedCommand::getHelpString(){
 		helpString += "The filter.shared command is used to remove OTUs based on various critieria.\n";
 		helpString += "The filter.shared command parameters are shared, minpercent, minabund, mintotal, minnumsamples, minpercentsamples, rarepercent, makerare, keepties, groups and label.  You must provide a shared file.\n";
 		helpString += "The groups parameter allows you to specify which of the groups you would like included. The group names are separated by dashes.\n";
+        helpString += "You may provide an accnos containing the list of groups to get instead of setting the groups parameter to the groups you wish to select.\n";
 		helpString += "The label parameter allows you to select what distance levels you would like, and are also separated by dashes.\n";
         
 		helpString += "The minabund parameter allows you indicate the minimum abundance required for each sample in a given OTU.  If any samples abundance falls below the minimum, the OTU is removed. Default=0\n";
@@ -114,7 +116,7 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 			//check to make sure all parameters are valid for command
 			map<string,string>::iterator it;
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -133,6 +135,14 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 					//if the user has not given a path then, add inputdir. else leave path alone.
 					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
 				}
+                
+                it = parameters.find("accnos");
+                //user has given a template file
+                if(it != parameters.end()){
+                    path = util.hasPath(it->second);
+                    //if the user has not given a path then, add inputdir. else leave path alone.
+                    if (path == "") {	parameters["accnos"] = inputDir + it->second;		}
+                }
             }
 					
 			sharedfile = validParameter.validFile(parameters, "shared");
@@ -163,7 +173,12 @@ FilterSharedCommand::FilterSharedCommand(string option) {
 				util.splitAtDash(groups, Groups);
                 if (Groups.size() != 0) { if (Groups[0]== "all") { Groups.clear(); } }
 			}
-			
+            
+            accnosfile = validParameter.validFile(parameters, "accnos");
+            if (accnosfile == "not open") { abort = true; }
+            else if (accnosfile == "not found") {  accnosfile = ""; }
+            else { current->setAccnosFile(accnosfile); util.readAccnos(accnosfile, Groups);  } //load groups in accnos file into Groups parameter
+
             bool setSomething = false;
 			string temp = validParameter.valid(parameters, "minabund");
             if (temp == "not found"){	temp = "-1";		}
@@ -185,7 +200,8 @@ FilterSharedCommand::FilterSharedCommand(string option) {
             else { setSomething = true; }
             
 			util.mothurConvert(temp, minPercent);
-            if (minPercent < 1) {} //already in percent form
+            if (minPercent == -1) { minPercent = -0.01; }
+            else if (minPercent < 1) {} //already in percent form
             else {  minPercent = minPercent / 100.0; } //user gave us a whole number version so convert to %
             
             temp = validParameter.valid(parameters, "rarepercent");
@@ -193,7 +209,8 @@ FilterSharedCommand::FilterSharedCommand(string option) {
             else { setSomething = true; }
             
 			util.mothurConvert(temp, rarePercent);
-            if (rarePercent < 1) {} //already in percent form
+            if (rarePercent == -1) { rarePercent = -0.01; }
+            else if (rarePercent < 1) {} //already in percent form
             else {  rarePercent = rarePercent / 100.0; } //user gave us a whole number version so convert to %
             
             temp = validParameter.valid(parameters, "minpercentsamples");
@@ -201,7 +218,8 @@ FilterSharedCommand::FilterSharedCommand(string option) {
             else { setSomething = true; }
             
 			util.mothurConvert(temp, minPercentSamples);
-            if (minPercentSamples < 1) {} //already in percent form
+            if (minPercentSamples == -1) { minPercentSamples = -0.01; }
+            else if (minPercentSamples < 1) {} //already in percent form
             else {  minPercentSamples = minPercentSamples / 100.0; } //user gave us a whole number version so convert to %
 			
 			temp = validParameter.valid(parameters, "makerare");		if (temp == "not found"){	temp = "T";		}
@@ -323,22 +341,18 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
         
         if (m->getControl_pressed()) {  return 0; }
         
-        map<string, int> labelsForRare;
-        vector<string> filteredLabels;
-        
-        vector<SharedRAbundVector*> data = sharedLookup->getSharedRAbundVectors();
         vector<int> rareCounts; rareCounts.resize(Groups.size(), 0);
+        int numGroups = Groups.size();
+        float defaultSetting = -0.01;
         
         //you want to remove a percentage of OTUs
         set<string> removeLabels;
-        if (rarePercent != -0.01) {
+        if (!util.isEqual(rarePercent, defaultSetting)) {
             vector<spearmanRank> otus;
             //rank otus by abundance
             for (int i = 0; i < sharedLookup->getNumBins(); i++) {
                 float otuTotal = 0.0;
-                for (int j = 0; j < data.size(); j++) {
-                    otuTotal += data[j]->get(i);
-                }
+                for (int j = 0; j < numGroups; j++) { otuTotal += sharedLookup->get(i, Groups[j]); }
                 spearmanRank temp(sharedLookup->getOTUName(i), otuTotal);
                 otus.push_back(temp);
             }
@@ -347,15 +361,15 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
             sort(otus.begin(), otus.end(), compareSpearman);
             
             //find index of cutoff
-            int indexFirstNotRare = ceil(rarePercent * (float)data[0]->getNumBins());
+            int indexFirstNotRare = ceil(rarePercent * (float)sharedLookup->getNumBins());
             
             //handle ties
             if (keepties) { //adjust indexFirstNotRare if needed
                 if (indexFirstNotRare != 0) { //not out of bounds
-                    if (otus[indexFirstNotRare].score == otus[indexFirstNotRare-1].score) { //you have a tie
+                    if (util.isEqual(otus[indexFirstNotRare].score, otus[indexFirstNotRare-1].score)) { //you have a tie
                         bool tie = true;
                         for (int i = indexFirstNotRare-1; i >=0; i--) {
-                            if (otus[indexFirstNotRare].score != otus[i].score) { //found value below tie
+                            if (!util.isEqual(otus[indexFirstNotRare].score, otus[i].score)) { //found value below tie
                                 indexFirstNotRare = i+1; tie = false; break;
                             }
                         }
@@ -372,29 +386,31 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
         int numRemoved = 0;
         for (int i = 0; i < sharedLookup->getNumBins();) {
             
-            if (m->getControl_pressed()) { for (int j = 0; j < data.size(); j++) { delete data[j]; } return 0; }
+            if (m->getControl_pressed()) { return 0; }
+            
+            vector<int> abunds = sharedLookup->getOTU(i);
             
             bool okay = true; //innocent until proven guilty
             if (minAbund != -1) {
-                for (int j = 0; j < data.size(); j++) {
-                    if (data[j]->get(i) < minAbund) { okay = false; break; }
+                for (int j = 0; j < numGroups; j++) {
+                    if (abunds[j] < minAbund) { okay = false; break; }
                 }
             }
             
             if (okay && (minTotal != -1)) {
                 int otuTotal = 0;
-                for (int j = 0; j < data.size(); j++) {
-                    otuTotal += data[j]->get(i);
+                for (int j = 0; j < numGroups; j++) {
+                    otuTotal += abunds[j];
                 }
                 if (otuTotal < minTotal) { okay = false; }
             }
             
-            if (okay && (minPercent != -0.01)) {
+            if (okay && (!util.isEqual(minPercent, defaultSetting))) {
                 double otuTotal = 0;
                 double total = 0;
-                for (int j = 0; j < data.size(); j++) {
-                    otuTotal += data[j]->get(i);
-                    total += data[j]->getNumSeqs();
+                for (int j = 0; j < numGroups; j++) {
+                    otuTotal += abunds[j];
+                    total += sharedLookup->getNumSeqs(Groups[j]);
                 }
                 double percent = otuTotal / total; 
                 if (percent < minPercent) { okay = false; }
@@ -403,23 +419,23 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
             
             if (okay && (minSamples != -1)) {
                 int samples = 0;
-                for (int j = 0; j < data.size(); j++) {
-                    if (data[j]->get(i) != 0) { samples++; }
+                for (int j = 0; j < numGroups; j++) {
+                    if (abunds[j] != 0) { samples++; }
                 }
                 if (samples < minSamples) { okay = false; }
             }
             
-            if (okay && (minPercentSamples != -0.01)) {
+            if (okay && (!util.isEqual(minPercentSamples, defaultSetting))) {
                 double samples = 0;
-                double total = data.size();
-                for (int j = 0; j < data.size(); j++) {
-                    if (data[j]->get(i) != 0) { samples++; }
+                double total = numGroups;
+                for (int j = 0; j < numGroups; j++) {
+                    if (abunds[j] != 0) { samples++; }
                 }
                 double percent = samples / total; 
                 if (percent < minPercentSamples) { okay = false; }
             }
             
-            if (okay && (rarePercent != -0.01)) {
+            if (okay && (!util.isEqual(rarePercent, defaultSetting))) {
                 if (removeLabels.count(sharedLookup->getOTUName(i)) != 0) { //are we on the 'bad' list
                     okay = false;
                 }
@@ -427,14 +443,15 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
             
             //did this OTU pass the filter criteria
             if (okay) {
-                //filteredLabels.push_back(saveBinLabels[i]);
-                //labelsForRare[util.getSimpleLabel(saveBinLabels[i])] = i;
                 ++i;
             }else { //if not, do we want to save the counts
                 filteredSomething = true;
                 if (makeRare) {
-                    for (int j = 0; j < rareCounts.size(); j++) {  rareCounts[j] += data[j]->get(i); }
+                    for (int j = 0; j < numGroups; j++) {
+                        rareCounts[j] += abunds[j];
+                    }
                 }
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: removing OTU " + sharedLookup->getOTUName(i) + "\n"); }
                 sharedLookup->removeOTU(i);
                 numRemoved++;
             }
@@ -442,42 +459,12 @@ int FilterSharedCommand::processShared(SharedRAbundVectors*& sharedLookup) {
         }
         
         //if we are saving the counts add a "rare" OTU if anything was filtered
-        if (makeRare) {
-            if (filteredSomething) {
-                //create label for rare OTUs
-                map<string, int>::iterator it;
-                int otuNum = 0; bool notDone = true;
-                
-                //find label prefix
-                string prefix = "Otu";
-                if (filteredLabels[filteredLabels.size()-1][0] == 'P') { prefix = "PhyloType"; }
-                
-                string tempLabel = filteredLabels[filteredLabels.size()-1];
-                string simpleLastLabel = util.getSimpleLabel(tempLabel);
-                util.mothurConvert(simpleLastLabel, otuNum); otuNum++;
-                while (notDone) {
-                    if (m->getControl_pressed()) { notDone = false; break; }
-                    
-                    string potentialLabel = toString(otuNum);
-                    it = labelsForRare.find(potentialLabel);
-                    if (it == labelsForRare.end()) {
-                        potentialLabel = prefix + toString(otuNum);
-                        it = labelsForRare.find(potentialLabel);
-                        if (it == labelsForRare.end()) {
-                            notDone = false; break;
-                        }
-                    }
-                    otuNum++;
-                }
-                sharedLookup->push_back(rareCounts, "rareOTUs" + toString(otuNum));
-                //filteredLabels.push_back("rareOTUs" + toString(otuNum));
-            }
-        }
+        if (makeRare) { if (filteredSomething) { sharedLookup->push_back(rareCounts, "OTURare1"); } }
         
         ofstream out;
 		util.openOutputFile(outputFileName, out);
-		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-        sharedLookup->print(out);
+		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);  bool printHeaders = true;
+        sharedLookup->print(out, printHeaders);
 		out.close();
         
         m->mothurOut("\nRemoved " + toString(numRemoved) + " OTUs.\n");
