@@ -128,7 +128,7 @@ GetGroupsCommand::GetGroupsCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -566,6 +566,7 @@ int GetGroupsCommand::readShared(){
         variables["[extension]"] = util.getExtension(sharedfile);
 		
 		bool wroteSomething = false;
+        bool printHeaders = true;
 		while(lookup != NULL) {
 			
             variables["[tag]"] = lookup->getLabel();
@@ -577,7 +578,7 @@ int GetGroupsCommand::readShared(){
 			
             if (m->getControl_pressed()) { out.close();  util.mothurRemove(outputFileName);  delete lookup; return 0; }
 			
-            lookup->print(out);
+            lookup->print(out, printHeaders);
             wroteSomething = true;
 			
 			//get next line to process
