@@ -119,7 +119,7 @@ GetMetaCommunityCommand::GetMetaCommunityCommand(string option)  {
 			map<string,string>::iterator it;
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
             vector<string> tempOutNames;
@@ -910,7 +910,6 @@ int GetMetaCommunityCommand::driver(SharedRAbundVectors*& thisLookup, vector< ve
                     if (m->getControl_pressed()) { for (int i = 0; i < data.size(); i++) { delete data[i]; } data.clear(); return 1; }
                     
                     seqDist temp(l, k, tempdata[0]);
-                    //cout << l << '\t' << k << '\t' <<  tempdata[0] << endl;
                     calcDists[0].push_back(temp);
                 }
 				
