@@ -107,7 +107,7 @@ GetOtuLabelsCommand::GetOtuLabelsCommand(string option)  {
 			map<string,string>::iterator it;
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			
@@ -478,8 +478,8 @@ int GetOtuLabelsCommand::readShared(){
         variables["[distance]"] = lookup->getLabel();
 		string outputFileName = getOutputFileName("shared", variables);
         outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-        ofstream out; util.openOutputFile(outputFileName, out);
-        lookup->print(out);
+        ofstream out; util.openOutputFile(outputFileName, out);  bool printHeaders = true;
+        lookup->print(out, printHeaders);
 		out.close();
         
         delete lookup;
