@@ -129,7 +129,7 @@ GetSeqsCommand::GetSeqsCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -509,7 +509,7 @@ int GetSeqsCommand::readFasta(){
         
         if (m->getDebug()) { set<string> temp; sanity["fasta"] = temp; }
 		
-        set<string> uniqueNames;
+        set<string> uniqueNames; int line = 0; int redundNum = 0;
 		while(!in.eof()){
 		
 			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(outputFileName);  return 0; }
@@ -525,6 +525,7 @@ int GetSeqsCommand::readFasta(){
             name = currSeq.getName();
             
 			if (name != "") {
+                line++;
 				//if this name is in the accnos file
 				if (names.count(name) != 0) {
                     if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
@@ -537,6 +538,7 @@ int GetSeqsCommand::readFasta(){
                         if (m->getDebug()) { sanity["fasta"].insert(name); }
                     }else {
                         m->mothurOut("[WARNING]: " + name + " is in your fasta file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                        redundNum++;
                     }
                 }
 			}
@@ -545,7 +547,6 @@ int GetSeqsCommand::readFasta(){
 		in.close();	
 		out.close();
 		
-		
 		if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file."); m->mothurOutEndLine();  }
 		outputNames.push_back(outputFileName);  outputTypes["fasta"].push_back(outputFileName); 
 		
@@ -872,7 +873,7 @@ int GetSeqsCommand::readName(){
                 }
             }
 
-			if ((dups) && (validSecond.size() != 0)) { //dups = true and we want to add someone, then add everyone
+			if (dups && (validSecond.size() != 0)) { //dups = true and we want to add someone, then add everyone
 				for (int i = 0; i < parsedNames.size(); i++) {  names.insert(parsedNames[i]); if (m->getDebug()) { sanity["dupname"].insert(parsedNames[i]); } }
 				out << firstCol << '\t' << hold << endl;
 				wroteSomething = true;
@@ -1297,7 +1298,7 @@ int GetSeqsCommand::compareAccnos(){
 			if (namesAccnos.count(name) == 0){ //name unique to accnos2
 				int pos = name.find_last_of('_');
 				string tempName = name;
-				if (pos != string::npos) {  tempName = tempName.substr(pos+1); cout << tempName << endl; }
+				if (pos != string::npos) {  tempName = tempName.substr(pos+1);  }
 				if (namesAccnos.count(tempName) == 0){
 					namesAccnos2.insert(name);
 				}else { //you are in both so erase
