@@ -135,7 +135,7 @@ LefseCommand::LefseCommand(string option)  {
 			map<string,string>::iterator it;
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			vector<string> tempOutNames;
@@ -152,7 +152,7 @@ LefseCommand::LefseCommand(string option)  {
 				if(it != parameters.end()){
 					path = util.hasPath(it->second);
 					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["desing"] = inputDir + it->second;		}
+					if (path == "") {	parameters["design"] = inputDir + it->second;		}
 				}
 				
                 it = parameters.find("shared");
@@ -218,10 +218,6 @@ LefseCommand::LefseCommand(string option)  {
 			if (temp == "not found") { temp = "T"; }
 			normMillion = util.isTrue(temp);
             
-            //temp = validParameter.validFile(parameters, "subject", false);
-			//if (temp == "not found") { temp = "F"; }
-			//subject = util.isTrue(temp);
-
             temp = validParameter.valid(parameters, "lda");
 			if (temp == "not found") { temp = "2.0"; }
 			util.mothurConvert(temp, ldaThreshold);
@@ -234,17 +230,13 @@ LefseCommand::LefseCommand(string option)  {
 			if (temp == "not found") { temp = "0.67"; }
 			util.mothurConvert(temp, fBoots);
             
-            //temp = validParameter.validFile(parameters, "wilcsamename", false);
-			//if (temp == "not found") { temp = "F"; }
-			//wilcsamename = util.isTrue(temp);
-            
             temp = validParameter.valid(parameters, "curv");
 			if (temp == "not found") { temp = "F"; }
 			curv = util.isTrue(temp);
             
             temp = validParameter.valid(parameters, "strict");
             if (temp == "not found"){	temp = "0";		}
-			if ((temp != "0") && (temp != "1") && (temp != "2")) { m->mothurOut("Invalid strict option: choices are 0, 1 or 2."); m->mothurOutEndLine(); abort=true; }
+			if ((temp != "0") && (temp != "1") && (temp != "2")) { m->mothurOut("[ERROR]: Invalid strict option: choices are 0, 1 or 2.\n");  abort=true; }
             else {  util.mothurConvert(temp, strict); }
             
             temp = validParameter.valid(parameters, "minc");
@@ -397,8 +389,7 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
                 subclass2Class[thisSub] = treatment;
                 vector<int> temp; temp.push_back(j);
                 subClass2GroupIndex[thisSub] = temp;
-            }
-            else {
+            }else {
                 if (it->second != treatment) {
                     //m->mothurOut("[WARNING]: subclass " + thisSub + " has members in " + it->second + " and " + treatment + ". Subclass members must be from the same class for Wilcoxon. Changing " + thisSub + " to " + treatment + "_" + thisSub + ".\n");
                     thisSub = treatment + "_" + thisSub;
@@ -571,7 +562,7 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
         map<string, set<string> >::iterator itB;
         for(map<string, set<string> >::iterator it=class2SubClasses.begin();it!=class2SubClasses.end();it++){
             itB = it;itB++;
-            for(itB;itB!=class2SubClasses.end();itB++){
+            for(;itB!=class2SubClasses.end();itB++){
                 if (m->getControl_pressed()) { return false; }
                 bool first = true;
                 int dirCmp = 0; // not set?? dir_cmp = "not_set" # 0=notset or none, 1=true, 2=false.
@@ -619,7 +610,7 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
                         double pValue = 0.0;
                         double H = 0.0;
                         bool tres = true; //don't think this is set in the python source.  Not sure how that is handled, but setting it here.
-                        if ((x[0] == y[0]) && (x.size() == 1) && (y.size() == 1)) { tres = false; first = false; }
+                        if (util.isEqual(x[0],y[0]) && (x.size() == 1) && (y.size() == 1)) { tres = false; first = false; }
                         else if (!medComp) {
                             H = linear.calcWilcoxon(x, y, pValue);
                             if (pValue < (alphaMtc*2.0)) { tres = true; }
@@ -654,7 +645,7 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
                             first = false;
                             if ((!curv) && (medComp || tres)) {
                                 dirCmp = 2; if (sx<sy) { dirCmp = 1; } //dir_cmp = sx < sy
-                                if (sx == sy) { br = true; }
+                                if (util.isEqual(sx,sy)) { br = true; }
                             }else if (curv) {
                                 dirCmp = 0;
                                 if (medComp || tres) {
@@ -663,7 +654,7 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
                                 }
                             }else { br = true; }
                         }else if (!curv && medComp) {
-                            if (sxSy != dirCmp || sx == sy) { br = true; }
+                            if (sxSy != dirCmp || util.isEqual(sx,sy)) { br = true; }
                         }else if (curv) {
                             if (tres && dirCmp == 0) { curv_sign++; }
                             dirCmp = 2; if (sx<sy) { dirCmp = 1; } //dir_cmp = sx < sy
@@ -671,7 +662,7 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
                                 br = true;
                                 curv_sign = -1;
                             }
-                        }else if (!tres || sxSy != dirCmp || sx == sy) { br = true; } //elif not tres or (sx < sy) != dir_cmp or sx == sy: br = True
+                        }else if (!tres || sxSy != dirCmp || util.isEqual(sx,sy)) { br = true; } //elif not tres or (sx < sy) != dir_cmp or sx == sy: br = True
                         if (br) { break; }
                         ok++;
                     }//for class2 subclasses
@@ -805,12 +796,6 @@ map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<in
             
             if (m->getDebug()) { m->mothurOut("[DEBUG]: after 1000. \n."); }
             
-            //print data in R input format for testing
-            if (false) {
-                //vector<string> groups; for (int h = 0; h < rand_s.size(); h++) {  groups.push_back(lookup[rand_s[h]]->getGroup()); }
-                //for (int h = 0; h < groups.size(); h++) { cout << groups[h]<< endl; }
-                //printToCoutForRTesting(adjustedLookup, rand_s, class2GroupIndex, bins, subClass2GroupIndex, groups);
-            }
             if (save < 1000) { m->mothurOut("[WARNING]: Skipping iter " + toString(j+1) + " in LDA test. This can be caused by too few groups per class or not enough contrast within the classes. \n"); }
             else {
                 //for each pair of classes
@@ -1077,16 +1062,7 @@ bool LefseCommand::printToCoutForRTesting(vector< vector<double> >& adjustedLook
             cout << (adjustedLookup[count][rand_s[rand_s.size()-1]]) << ")\n";
             count++;
         }
-        /*
-        string tempOutput = "";
-        for (int h = 0; h < rand_s.size(); h++) {
-            //find class this index is in
-            for (map<string, vector<int> >::iterator it = class2GroupIndex.begin(); it!= class2GroupIndex.end(); it++) {
-                if (util.inUsersGroups(rand_s[h], (it->second)) ) {   cout << (h+1) << " <- c(\"" +it->first + "\")\n" ; }
-            }
-        }*/
         
-       
         string tempOutput = "treatments <- c(";
         for (int h = 0; h < rand_s.size(); h++) {
             //find class this index is in
@@ -1098,31 +1074,6 @@ bool LefseCommand::printToCoutForRTesting(vector< vector<double> >& adjustedLook
         tempOutput += ")\n";
         cout << tempOutput;
         
-         /*
-        if (subclass != "") {
-            string tempOutput = "sub <- c(";
-            for (int h = 0; h < rand_s.size(); h++) {
-                //find class this index is in
-                for (map<string, vector<int> >::iterator it = subClass2GroupIndex.begin(); it!= subClass2GroupIndex.end(); it++) {
-                    if (util.inUsersGroups(rand_s[h], (it->second)) ) {   tempOutput += "\"" +it->first + "\"" + ','; }
-                }
-            }
-            tempOutput = tempOutput.substr(0, tempOutput.length()-1);
-            tempOutput += ")\n";
-            cout << tempOutput;
-        }
-        
-        if (subject) {
-            string tempOutput = "group <- c(";
-            for (int h = 0; h < groups.size(); h++) {
-                tempOutput += "\"" +groups[h] + "\"" + ','; 
-            }
-            tempOutput = tempOutput.substr(0, tempOutput.length()-1);
-            tempOutput += ")\n";
-            cout << tempOutput;
-        }*/
-
-        
         //print data frame
         tempOutput = "dat <- data.frame(";
         for (map<int, double>::iterator it = bins.begin(); it != bins.end(); it++) {
@@ -1130,10 +1081,8 @@ bool LefseCommand::printToCoutForRTesting(vector< vector<double> >& adjustedLook
             
             tempOutput += "\"" + currentLabels[it->first] + "\"=" + currentLabels[it->first] + ",";
         }
-        //tempOutput = tempOutput.substr(0, tempOutput.length()-1);
+        
         tempOutput += " class=treatments";
-        //if (subclass != "") { tempOutput += ", subclass=sub"; }
-        //if (subject) { tempOutput += ", subject=group"; }
         tempOutput += ")\n";
         cout << tempOutput;
                 
@@ -1149,8 +1098,6 @@ bool LefseCommand::printToCoutForRTesting(vector< vector<double> >& adjustedLook
         cout << "w <- z$scaling[,1]\n"; //robjects.r('w <- z$scaling[,1]')
         cout << "w.unit <- w/sqrt(sum(w^2))\n"; //robjects.r('w.unit <- w/sqrt(sum(w^2))')
         cout << "ss <- dat[,-match(\"class\",colnames(dat))]\n"; //robjects.r('ss <- sub_d[,-match("class",colnames(sub_d))]')
-        //if (subclass != "") { cout << "ss <- ss[,-match(\"subclass\",colnames(ss))]\n";  }//robjects.r('ss <- ss[,-match("subclass",colnames(ss))]')
-        //if (subject) { cout << "ss <- ss[,-match(\"subject\",colnames(ss))]\n";  }//robjects.r('ss <- ss[,-match("subject",colnames(ss))]')
         cout << "xy.matrix <- as.matrix(ss)\n"; //robjects.r('xy.matrix <- as.matrix(ss)')
         cout << "LD <- xy.matrix%*%w.unit\n"; //robjects.r('LD <- xy.matrix%*%w.unit')
         cout << "effect.size <- abs(mean(LD[dat[,\"class\"]==\"'+p[0]+'\"]) - mean(LD[dat[,\"class\"]==\"'+p[1]+'\"]))\n"; //robjects.r('effect.size <- abs(mean(LD[sub_d[,"class"]=="'+p[0]+'"]) - mean(LD[sub_d[,"class"]=="'+p[1]+'"]))')
