@@ -193,7 +193,7 @@ MakeBiomCommand::MakeBiomCommand(string option) {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 
 			//initialize outputTypes
@@ -741,7 +741,7 @@ int MakeBiomCommand::getBiom(SharedRAbundFloatVectors*& lookup){
                     float abund = binAbund[j];
                     string binInfo = "[" + toString(i) + "," + toString(j) + "," + toString(abund) + "]";
                     //only print non zero values
-                    if (abund != 0) { dataRows.push_back(binInfo); }
+                    if (!util.isEqual(abund, 0)) { dataRows.push_back(binInfo); }
                 }
             }
         }else {
@@ -1159,8 +1159,8 @@ int MakeBiomCommand::getGreenGenesOTUIDs(SharedRAbundVectors*& lookup, map<strin
         variables["[distance]"] = lookup->getLabel();
         string outputFileName = getOutputFileName("shared",variables);
         outputNames.push_back(outputFileName); outputTypes["shared"].push_back(outputFileName);
-		ofstream out; util.openOutputFile(outputFileName, out);
-        lookup->print(out);
+        ofstream out; util.openOutputFile(outputFileName, out);  bool printHeaders = true;
+        lookup->print(out, printHeaders);
         out.close();
 
         return 0;
@@ -1325,8 +1325,8 @@ int MakeBiomCommand::getGreenGenesOTUIDs(SharedRAbundFloatVectors*& lookup, map<
         variables["[distance]"] = lookup->getLabel();
         string outputFileName = getOutputFileName("relabund",variables);
         outputNames.push_back(outputFileName); outputTypes["relabund"].push_back(outputFileName);
-        ofstream out; util.openOutputFile(outputFileName, out);
-        lookup->print(out);
+        ofstream out; util.openOutputFile(outputFileName, out);  bool printHeaders = true;
+        lookup->print(out, printHeaders);
         out.close();
         
         return 0;
