@@ -113,7 +113,7 @@ MetaStatsCommand::MetaStatsCommand(string option) {
 			//check to make sure all parameters are valid for command
 			map<string,string>::iterator it;
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -229,7 +229,7 @@ int MetaStatsCommand::execute(){
 		set<string> userLabels = labels;
 		
         if (Sets.size() == 0) { Sets = designMap->getCategory();  }
-		int numGroups = Sets.size();
+		int numGroups = (int)Sets.size();
 		for (int a=0; a<numGroups; a++) { 
 			for (int l = 0; l < a; l++) {	
 				vector<string> groups; groups.push_back(Sets[a]); groups.push_back(Sets[l]);
