@@ -37,7 +37,7 @@ public:
 	
 	
 private:
-	int nIters, subsampleSize, iters;
+	int nIters, subsampleSize, iters, processors;
 	string format;
 	float freq;
 	
