@@ -131,7 +131,7 @@ RemoveLineageCommand::RemoveLineageCommand(string option)  {
 			
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -847,7 +847,7 @@ int RemoveLineageCommand::readShared(){
         if (m->getControl_pressed()) { delete lookup; return 0; }
         
         vector<string> newLabels;
-        bool wroteSomething = false;
+        bool wroteSomething = false; bool printHeaders = true;
         int numRemoved = 0;
         for (int i = 0; i < lookup->getNumBins();) {
             
@@ -870,7 +870,7 @@ int RemoveLineageCommand::readShared(){
         ofstream out;
 		util.openOutputFile(outputFileName, out);
 		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-        lookup->print(out);
+        lookup->print(out, printHeaders);
 		out.close();
         
         if (wroteSomething == false) { m->mothurOut("Your file only contains OTUs from " + taxons + "."); m->mothurOutEndLine();  }
@@ -1078,7 +1078,6 @@ int RemoveLineageCommand::readConsTax(){
 		util.openInputFile(constaxonomy, in);
 		string otuLabel, tax;
         int numReps;
-        bool wroteSomething = false;
         
         //read headers
         string headers = util.getline(in);
