@@ -106,7 +106,7 @@ RemoveOtuLabelsCommand::RemoveOtuLabelsCommand(string option)  {
 			map<string,string>::iterator it;
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			
@@ -274,6 +274,9 @@ int RemoveOtuLabelsCommand::execute(){
             if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setConsTaxonomyFile(currentName); }
         }
         
+        m->mothurOut("\nOutput File Names:\n");
+        for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	} m->mothurOutEndLine();
+        
         return 0;
     }
 	catch(exception& e) {
@@ -473,8 +476,8 @@ int RemoveOtuLabelsCommand::readShared(){
         variables["[distance]"] = lookup->getLabel();
 		string outputFileName = getOutputFileName("shared", variables);
         outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-        ofstream out; util.openOutputFile(outputFileName, out);
-        lookup->print(out);
+        ofstream out; util.openOutputFile(outputFileName, out);  bool printHeaders = true;
+        lookup->print(out, printHeaders);
         out.close();
         
         delete lookup;
