@@ -121,7 +121,7 @@ RenameSeqsCommand::RenameSeqsCommand(string option)  {
             
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			vector<string> tempOutNames;
@@ -390,10 +390,10 @@ int RenameSeqsCommand::execute() {
                         group = groupMap->getGroup(dups[i]);
                     }else if (countfile != "") {
                         if (hasGroups) {
-                            vector<string> groups = countTable->getGroups(seq.getName());
-                            if (group.size() == 0)      {   group = "not found";    }
-                            else if (group.size() == 1) {   group = groups[0];      }
-                            else                        {   group = "Multi";        }
+                            vector<string> thisReadsGroups = countTable->getGroups(seq.getName());
+                            if (thisReadsGroups.size() == 0)        {   group = "not found";            }
+                            else if (thisReadsGroups.size() == 1)   {   group = thisReadsGroups[0];     }
+                            else                                    {   group = "Multi";                }
                         }
                     }
                     
@@ -411,14 +411,14 @@ int RenameSeqsCommand::execute() {
                             else if (group != "") { newName = group + delim + newName; }
                         }
                         
+                        if (countfile != "") { countTable->renameSeq(seq.getName(), newName); }
+                        if (groupfile != "") { outGroup << newName << '\t' << group << endl;  }
+                        
                         if (i == 0) {
                             seq.setName(newName);
                             seq.printSequence(outFasta);
                         }
                         
-                        if (countfile != "") { countTable->renameSeq(seq.getName(), newName); }
-                        if (groupfile != "") { outGroup << newName << '\t' << group << endl;  }
-                        
                         if ((nameFile != "") && (i == 0))  { outName << newName << '\t' << newName;  }
                         else { outName << "," << newName;  }
                         
@@ -458,8 +458,7 @@ int RenameSeqsCommand::execute() {
         
         if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]);  } return 0; }
 
-        m->mothurOutEndLine();
-        m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+        m->mothurOut("\nOutput File Names:\n ");
         for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
         m->mothurOutEndLine();
         
@@ -559,13 +558,14 @@ int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
         
         map<string, string>::iterator it;
         int length, OLength, thisOStart, thisOEnd, numMisMatches, numNs;
+        double expectedErrors;
         string name;
         while (!in.eof()) {
             
             if (m->getControl_pressed()) { break; }
             
             //seqname	start	end	nbases	ambigs	polymer	numSeqs
-            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numNs; util.gobble(in);
+            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numNs >> expectedErrors; util.gobble(in);
             
             it = oldMap.find(name);
             if (it == oldMap.end()) {
@@ -574,7 +574,8 @@ int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
                 name = it->second;
             }
 
-            out << name << '\t' << length  << '\t' << OLength  << '\t' << thisOStart  << '\t' << thisOEnd  << '\t' << numMisMatches  << '\t' << numNs << endl;
+            out << name << '\t' << length  << '\t' << OLength  << '\t' << thisOStart  << '\t' << thisOEnd  << '\t' << numMisMatches  << '\t' << numNs << '\t' << expectedErrors << endl;
+
         }
         in.close();
         out.close();
@@ -750,34 +751,33 @@ int RenameSeqsCommand::processFile(map<string, string>& readMap){
 vector<map<string, string> > RenameSeqsCommand::readFiles(){
     try {
         
+        FileFile dataFile(fileFile, "renameSeqs");
+        vector< vector<string> > dataFiles = dataFile.getFiles();
+        int dataFileFormat = dataFile.getFileFormat();
+        map<int, string> file2Group = dataFile.getFile2Group();
+        
+        if (dataFileFormat == 3) { //4 column
+            m->mothurOut("[ERROR]: Your file contains " + toString(4) + " columns. The rename.seqs file option allows you to provide a 2 or 3 column file. The first column contains the file type: fasta or qfile. The second column is the filename, and the optional third column can be a group name. If there is a third column, all sequences in the file will be assigned to that group.  This can be helpful when renaming data separated into samples.\n"); m->setControl_pressed(true);
+        }
+
         vector<map<string, string> > files;
-        
-        ifstream in;
-        util.openInputFile(fileFile, in);
-        
-        while (!in.eof()) {
-            if (m->getControl_pressed()) { break; }
-            
-            string line = util.getline(in);  util.gobble(in);
-            vector<string> pieces = util.splitWhiteSpace(line);
-            
+        for (int i = 0; i < dataFiles.size(); i++) {
             string group = "";
             string thisFileName; thisFileName = "";
-            if (pieces.size() == 2) {
-                thisFileName = pieces[0]+"-"+pieces[1];
-            }else if (pieces.size() == 3) {
-                thisFileName = pieces[0]+"-"+pieces[1];
-                group = pieces[2];
-                util.checkGroupName(group);
-            }else {
-                m->mothurOut("[ERROR]: Your file contains " + toString(pieces.size()) + " columns. TThe file option allows you to provide a 2 or 3 column file. The first column contains the file type: fasta or qfile. The second column is the filename, and the optional third column can be a group name. If there is a third column, all sequences in the file will be assigned to that group.  This can be helpful when renaming data separated into samples.\n"); m->setControl_pressed(true);
+            string thisFileName1, thisFileName2;
+            thisFileName1 = dataFiles[i][0]; thisFileName2 = dataFiles[i][1];
+            
+            if (dataFileFormat == 1) { //2 column
+                thisFileName = thisFileName1+"-"+thisFileName2;
+            }else if (dataFileFormat == 2) { //3 column
+                thisFileName = thisFileName1+"-"+thisFileName2;
+                group = file2Group[i];
             }
             
             map<string, string> temp; temp[thisFileName] = group;
             files.push_back(temp);
         }
-        in.close();
-        
+
         return files;
     }
     catch(exception& e) {
