@@ -58,7 +58,7 @@ SetSeedCommand::SetSeedCommand(string option)  {
             ValidParameters validParameter;
             //check to make sure all parameters are valid for command
             for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) {
-                if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
             }
             
             bool seed = false;
