@@ -132,7 +132,7 @@ SubSampleCommand::SubSampleCommand(string option) {
 			//check to make sure all parameters are valid for command
 			map<string,string>::iterator it;
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -837,6 +837,7 @@ int SubSampleCommand::getSubSampleShared() {
 		if (lookup->size() == 0) {  m->mothurOut("The size you selected is too large, skipping shared file."); m->mothurOutEndLine();  return 0; }
 		
 		m->mothurOut("Sampling " + toString(size) + " from each group."); m->mothurOutEndLine();
+        bool printHeaders = true;
 		
 		//as long as you are not at the end of the file or done wih the lines you want
 		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
@@ -846,7 +847,7 @@ int SubSampleCommand::getSubSampleShared() {
 				
 				m->mothurOut(lookup->getLabel()+"\n"); 
 				
-				processShared(lookup);
+				processShared(lookup, printHeaders);
 				
 				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 			}
@@ -859,7 +860,7 @@ int SubSampleCommand::getSubSampleShared() {
 				lookup = input.getSharedRAbundVectors(lastLabel);
 				m->mothurOut(lookup->getLabel()+"\n"); 
 				
-				processShared(lookup);
+				processShared(lookup, printHeaders);
 				
 				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
 				
@@ -893,7 +894,7 @@ int SubSampleCommand::getSubSampleShared() {
 			
 			m->mothurOut(lookup->getLabel()+"\n"); 
 			
-			processShared(lookup);
+			processShared(lookup, printHeaders);
 			
 			if (lookup != NULL) { delete lookup; lookup = NULL; }
 		}
@@ -907,7 +908,7 @@ int SubSampleCommand::getSubSampleShared() {
 	}
 }
 //**********************************************************************************************************************
-int SubSampleCommand::processShared(SharedRAbundVectors*& thislookup) {
+int SubSampleCommand::processShared(SharedRAbundVectors*& thislookup, bool& printHeaders) {
 	try {
         string thisOutputDir = outputDir;
 		if (outputDir == "") {  thisOutputDir += util.hasPath(sharedfile);  }
@@ -925,7 +926,7 @@ int SubSampleCommand::processShared(SharedRAbundVectors*& thislookup) {
         ofstream out;
 		util.openOutputFile(outputFileName, out);
 		outputTypes["shared"].push_back(outputFileName);  outputNames.push_back(outputFileName);
-		thislookup->print(out);
+		thislookup->print(out, printHeaders);
         out.close();
 		
 		return 0;
@@ -1232,8 +1233,8 @@ int SubSampleCommand::getSubSampleList() {
                 
                 //use unique.seqs to create new name and fastafile
                 string inputString = "dups=f, name=" + namefile + ", taxonomy=" + taxonomyfile + ", accnos=" + tempAccnos;
-                m->mothurOut("/******************************************/"); m->mothurOutEndLine();
-                m->mothurOut("Running command: get.seqs(" + inputString + ")"); m->mothurOutEndLine();
+                m->mothurOut("/******************************************/\n");
+                m->mothurOut("Running command: get.seqs(" + inputString + ")\n"); 
                 current->setMothurCalling(true);
                 
                 Command* getCommand = new GetSeqsCommand(inputString);
@@ -1250,9 +1251,7 @@ int SubSampleCommand::getSubSampleList() {
                 outputTypes["name"].push_back(outputNameFileName);  outputNames.push_back(outputNameFileName);
                 outputNames.push_back(outputTaxFileName); outputTypes["taxonomy"].push_back(outputTaxFileName);
                 
-                m->mothurOut("/******************************************/"); m->mothurOutEndLine(); 
-                
-                m->mothurOut("Done."); m->mothurOutEndLine();
+                m->mothurOut("/******************************************/\nDone.\n");
             }
         }
 						
