@@ -121,7 +121,7 @@ TreeGroupCommand::TreeGroupCommand(string option)  {
 		
 			//check to make sure all parameters are valid for command
 			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (validParameter.isValidParameter(it->first, myArray, it->second) != true) {  abort = true;  }
+				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
 			}
 			
 			//initialize outputTypes
@@ -277,7 +277,7 @@ TreeGroupCommand::TreeGroupCommand(string option)  {
                 else { subsample = false; }
             }
             
-            if (subsample == false) { iters = 1; }
+            if (!subsample) { iters = 1; }
             
             if (subsample && (format != "sharedfile")) { m->mothurOut("[ERROR]: the subsample parameter can only be used with a shared file.\n"); abort=true; }
             
@@ -758,8 +758,8 @@ int process(treeSharedData* params) {
                         int column = calcDists[i][j].seq2;
                         double dist = calcDists[i][j].dist;
                         
-                        matrix[row][column] = dist;
-                        matrix[column][row] = dist;
+                        matrix[row][column] = -(dist-1.0);
+                        matrix[column][row] = -(dist-1.0);
                     }
                     params->matrices.push_back(matrix);
                 }
