@@ -489,21 +489,9 @@ int CommunityTypeFinder::findkMeans(){
             }
             
             iteration++;
-            //        cout << "K means: " << iteration << '\t' << maxChange << endl;
-            
         }
         
-        //    cout << "Iter:-1";
-        for(int i=0;i<numPartitions;i++){
-            weights[i] = 0.0000;
-            
-            for(int j=0;j<numSamples;j++){
-                weights[i] += zMatrix[i][j];
-            }
-            //        printf("\tw_%d=%.3f", i, weights[i]);
-        }
-        //    cout << endl;
-        
+        for(int i=0;i<numPartitions;i++){ weights[i] = 0.0000; for(int j=0;j<numSamples;j++){  weights[i] += zMatrix[i][j]; } }
         
         for(int i=0;i<numOTUs;i++){
             if (m->getControl_pressed()) {  return 0; }
@@ -651,8 +639,6 @@ vector<vector<double> > CommunityTypeFinder::calcCenters(vector<vector<double> >
     try {
         //for each partition
         //choose sample with smallest sum of squared dists
-        //       cout << "Here" << clusterMap.size() << endl;
-        //       for(map<int, int>::iterator it = clusterMap.begin(); it != clusterMap.end(); it++) { cout << it->first << '\t' << it->second <<endl; }
         vector<vector<double> > centers; centers.resize(numPartitions);
         vector<double>  sums;  sums.resize(numSamples, 0.0);
         map<int, vector<int> > partition2Samples; //maps partitions to samples in the partition
@@ -796,7 +782,7 @@ vector<double> CommunityTypeFinder::calcSilhouettes(vector<vector<double> > dist
             }
             
             silhouettes[i] = 0.0;
-            if (computeSi && bi != ai) {
+            if (computeSi && !util.isEqual(bi, ai)) {
                 silhouettes[i] = (bi-ai) / (max(ai, bi));
             }
         }
