@@ -29,8 +29,7 @@ void FastaMap::readFastaFile(string inFileName) {
 			name = currSeq.getName();
 			
 			if (name != "") {
-				if(currSeq.getIsAligned())	{	sequence = currSeq.getAligned();	}
-				else						{	sequence = currSeq.getUnaligned();	}
+				sequence = currSeq.getAligned();
 				
 				itName = seqmap.find(name);
 				if (itName == seqmap.end()) { seqmap[name] = sequence;  }
@@ -86,8 +85,7 @@ void FastaMap::readFastaFile(string inFastaFile, string oldNameFileName){ //prin
 		name = currSeq.getName();
 		
 		if (name != "") {
-			if(currSeq.getIsAligned())	{	sequence = currSeq.getAligned();	}
-			else						{	sequence = currSeq.getUnaligned();	}
+			sequence = currSeq.getAligned();
 			
 			itName = seqmap.find(name);
 			if (itName == seqmap.end()) { seqmap[name] = sequence;  }
