@@ -10,7 +10,7 @@
 #include "rabundvector.hpp"
 #include "sabundvector.hpp"
 #include "ordervector.hpp"
-#include "calculator.h"
+#include "rabundfloatvector.hpp"
 
 
 /***********************************************************************/
@@ -45,6 +45,17 @@ RAbundVector::RAbundVector(string id, vector<int> rav) : DataVector(id), data(ra
 		exit(1);
 	}
 }
+/***********************************************************************/
+
+RAbundVector::RAbundVector(vector<int> rav) :  DataVector(), maxRank(0), numBins(0), numSeqs(0)  {
+    try {
+        for(int i=0;i<rav.size();i++){ set(i, rav[i]); }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "RAbundVector", "RAbundVector");
+        exit(1);
+    }
+}
 
 /***********************************************************************/
 
@@ -60,19 +71,38 @@ RAbundVector::RAbundVector(vector<int> rav, int mr, int nb, int ns) {
 		exit(1);
 	}
 }
-
 /***********************************************************************/
 
 
 RAbundVector::RAbundVector(ifstream& f) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
+    try {
+        int hold;
+        f >> label >> hold;
+        
+        data.assign(hold, 0);
+        int inputData;
+        
+        for(int i=0;i<hold;i++){
+            f >> inputData;
+            set(i, inputData);
+        }
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "RAbundVector", "RAbundVector");
+        exit(1);
+    }
+}
+
+/***********************************************************************/
+RAbundVector::RAbundVector(ifstream& f, string l) : DataVector(), maxRank(0), numBins(0), numSeqs(0) {
 	try {
-		int hold;
-		f >> label >> hold;
+        label = l;
+		f >> numBins;
+        data.assign(numBins, 0);
 	
-		data.assign(hold, 0);
 		int inputData;
-	
-		for(int i=0;i<hold;i++){
+		for(int i=0;i<numBins;i++){
 			f >> inputData;
 			set(i, inputData);
 		}
@@ -142,7 +172,28 @@ void RAbundVector::push_back(int binSize){
 		exit(1);
 	}
 }
+/***********************************************************************/
 
+int RAbundVector::remove(int bin){
+    try {
+        int abund = data[bin];
+        data.erase(data.begin()+bin);
+        numBins--;
+        
+        if(abund == maxRank){
+            vector<int>::iterator it = max_element(data.begin(), data.end());
+            maxRank = *it;
+        }
+        
+        numSeqs -= abund;
+        
+        return abund;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "RAbundVector", "remove");
+        exit(1);
+    }
+}
 /***********************************************************************/
 
 void RAbundVector::pop_back(){
@@ -172,24 +223,32 @@ void RAbundVector::quicksort(){
 /***********************************************************************/
 
 int RAbundVector::sum(){
-	VecCalc vecCalc;
-	return vecCalc.sumElements(data);
+    Utils util;
+	return util.sum(data);
 }
 
 /***********************************************************************/
 
 int RAbundVector::sum(int index){
-	VecCalc vecCalc;
-	return vecCalc.sumElements(data, index);
+    int sum = 0;
+    for(int i = index; i < data.size(); i++) {  sum += data[i];  }
+	return sum;
 }
 
 /***********************************************************************/
 
 int RAbundVector::numNZ(){
-	VecCalc vecCalc;
-	return vecCalc.numNZ(data);
+    int numNZ = 0;
+    for(int i = 0; i < data.size(); i++) { if(data[i] != 0) { numNZ++; } }
+	return numNZ;
 }
+/***********************************************************************/
 
+vector<int> RAbundVector::getSortedD(){
+    vector<int> temp; temp = data;
+    sort(temp.begin()+1, temp.end());
+    return temp;
+}
 /***********************************************************************/
 
 vector<int>::reverse_iterator RAbundVector::rbegin(){
@@ -205,7 +264,8 @@ vector<int>::reverse_iterator RAbundVector::rend(){
 /***********************************************************************/
 void RAbundVector::nonSortedPrint(ostream& output){
 	try {	
-		output << label << '\t' << numBins;
+        output << label;
+        output << '\t' << numBins;
 	
 		for(int i=0;i<numBins;i++){		output  << '\t' << data[i];		}
 		output << endl;
@@ -215,28 +275,11 @@ void RAbundVector::nonSortedPrint(ostream& output){
 		exit(1);
 	}
 }
-/***********************************************************************/
-void RAbundVector::print(string prefix, ostream& output){
-	try {	
-		output << prefix << '\t' << numBins;
-	
-		vector<int> hold = data;
-		sort(hold.rbegin(), hold.rend());
-	
-		for(int i=0;i<numBins;i++){		output  << '\t' << hold[i];		}
-		output << endl;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RAbundVector", "print");
-		exit(1);
-	}
-}
-
-
 /***********************************************************************/
 void RAbundVector::print(ostream& output){
 	try {
-		output << label << '\t' << numBins;
+        output << label;
+        output << '\t' << numBins;
 	
 		vector<int> hold = data;
 		sort(hold.rbegin(), hold.rend());
@@ -249,7 +292,6 @@ void RAbundVector::print(ostream& output){
 		exit(1);
 	}
 }
-
 /***********************************************************************/
 int RAbundVector::getNumBins(){
 	return numBins;
@@ -272,6 +314,13 @@ int RAbundVector::getMaxRank(){
 RAbundVector RAbundVector::getRAbundVector(){
 	return *this;			
 }
+/***********************************************************************/
+
+RAbundFloatVector RAbundVector::getRAbundFloatVector(){
+    RAbundFloatVector rav; rav.setLabel(label);
+    for(int i=0;i<data.size();i++){ rav.push_back(0.0 + data[i]);  }
+    return rav;
+}
 
 /***********************************************************************/
 
@@ -304,7 +353,7 @@ OrderVector RAbundVector::getOrderVector(map<string,int>* nameMap = NULL) {
 				ov.push_back(i);
 			}
 		}
-		m->mothurRandomShuffle(ov);
+		util.mothurRandomShuffle(ov);
 		ov.setLabel(label);	
 		ov.getNumBins();
 
