@@ -31,7 +31,7 @@ SharedRAbundFloatVector::SharedRAbundFloatVector(vector<float> rav) :  DataVecto
 
 /***********************************************************************/
 
-SharedRAbundFloatVector::SharedRAbundFloatVector(vector<float> rav, int mr, int nb, int ns) :  DataVector(), group(""){
+SharedRAbundFloatVector::SharedRAbundFloatVector(vector<float> rav, float mr, int nb, float ns) :  DataVector(), group(""){
     try {
         numBins = nb;
         maxRank = mr;
@@ -154,7 +154,15 @@ float SharedRAbundFloatVector::remove(int bin){
     }
 }
 /***********************************************************************/
-void SharedRAbundFloatVector::resize(int size){ data.resize(size); }
+void SharedRAbundFloatVector::resize(int size){
+    data.resize(size);
+    
+    vector<float>::iterator it = max_element(data.begin(), data.end());
+    maxRank = *it;
+    numSeqs = util.sum(data);
+    numBins = size;
+
+}
 /***********************************************************************/
 int SharedRAbundFloatVector::size(){ return data.size(); }
 /***********************************************************************/
@@ -197,6 +205,14 @@ RAbundVector SharedRAbundFloatVector::getRAbundVector(){
 }
 /***********************************************************************/
 
+RAbundFloatVector SharedRAbundFloatVector::getRAbundFloatVector(){
+    RAbundFloatVector rav;
+    for(int i = 0; i < data.size(); i++) { rav.push_back(data[i]); }
+    rav.setLabel(label);
+    return rav;
+}
+/***********************************************************************/
+
 SharedRAbundVector SharedRAbundFloatVector::getSharedRAbundVector(){
     SharedRAbundVector rav; rav.setLabel(label); rav.setGroup(group);
     for(int i = 0; i < data.size(); i++) { rav.push_back(int(data[i])); }
