@@ -436,7 +436,7 @@ void Tree::getSubTree(Tree* Ctree, vector<string> Groups) {
 							}
 						}else{
 							copy->tree[parent].setParent(-1);
-							//cout << "issues with making subtree" << endl;
+							
 						}
 						removedLeaves.insert(sibIndex);
 						removedLeaves.insert(i);
@@ -879,8 +879,7 @@ int Tree::findRoot() {
 		for (int i = 0; i < numNodes; i++) {
 			//you found the root
 			if (tree[i].getParent() == -1) { return i; }
-			//cout << "i = " << i << endl;
-			//cout << "i's parent = " << tree[i].getParent() << endl;  
+			
 		}
 		return -1;
 	}
@@ -901,7 +900,7 @@ try {
 			out << ")";
 			
             //if there is a branch length then print it
-            if (tree[node].getBranchLength() != -1) {
+            if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                 out << ":" << tree[node].getBranchLength();
             }
 			
@@ -916,7 +915,7 @@ try {
                 
                 if (dupNames.size() == 1) {
                     outputString += tree[node].getName();
-                    if (tree[node].getBranchLength() != -1) {
+                    if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                         outputString += ":" + toString(tree[node].getBranchLength());
                     }
                 }else {
@@ -925,26 +924,26 @@ try {
                     for (int u = 0; u < dupNames.size()-1; u++) {
                         outputString += dupNames[u];
                         
-                        if (tree[node].getBranchLength() != -1) {
+                        if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                             outputString += ":" + toString(0.0);
                         }
                         outputString += ",";
                     }
                     
                     outputString += dupNames[dupNames.size()-1];
-                    if (tree[node].getBranchLength() != -1) {
+                    if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                         outputString += ":" + toString(0.0);
                     }
                     
                     outputString += ")";
-                    if (tree[node].getBranchLength() != -1) {
+                    if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                         outputString += ":" + toString(tree[node].getBranchLength());
                     }
                 }
             }else { 
                 outputString = tree[node].getName();
                 //if there is a branch length then print it
-                if (tree[node].getBranchLength() != -1) {
+                if (!util.isEqual(tree[node].getBranchLength(), -1)) {
                     outputString += ":" + toString(tree[node].getBranchLength());
                 }
                 
@@ -973,7 +972,7 @@ void Tree::printBranch(int node, ostream& out, string mode) {
 			out << ")";
 			if (mode == "branch") {
 				//if there is a branch length then print it
-				if (tree[node].getBranchLength() != -1) {
+				if (!util.isEqual(tree[node].getBranchLength(), -1)) {
 					out << ":" << tree[node].getBranchLength();
 				}
 			}else if (mode == "boot") {
@@ -986,7 +985,7 @@ void Tree::printBranch(int node, ostream& out, string mode) {
 					out << tree[node].getLabel();
 				}
 				//if there is a branch length then print it
-				if (tree[node].getBranchLength() != -1) {
+				if (!util.isEqual(tree[node].getBranchLength(), -1)) {
 					out << ":" << tree[node].getBranchLength();
 				}
 			}
@@ -996,7 +995,7 @@ void Tree::printBranch(int node, ostream& out, string mode) {
 			if (mode == "branch") {
 				out << leafGroup[0]; 
 				//if there is a branch length then print it
-				if (tree[node].getBranchLength() != -1) {
+				if (!util.isEqual(tree[node].getBranchLength(), -1)) {
 					out << ":" << tree[node].getBranchLength();
 				}
 			}else if (mode == "boot") {
@@ -1011,7 +1010,7 @@ void Tree::printBranch(int node, ostream& out, string mode) {
 					out << tree[node].getLabel();
 				}
 				//if there is a branch length then print it
-				if (tree[node].getBranchLength() != -1) {
+				if (!util.isEqual(tree[node].getBranchLength(), -1)) {
 					out << ":" << tree[node].getBranchLength();
 				}
 			}
@@ -1036,7 +1035,7 @@ void Tree::printBranch(int node, ostream& out, string mode, vector<Node>& theseN
 			out << ")";
 			if (mode == "branch") {
 				//if there is a branch length then print it
-				if (theseNodes[node].getBranchLength() != -1) {
+				if (!util.isEqual(theseNodes[node].getBranchLength(), -1)) {
 					out << ":" << theseNodes[node].getBranchLength();
 				}
 			}else if (mode == "boot") {
@@ -1049,7 +1048,7 @@ void Tree::printBranch(int node, ostream& out, string mode, vector<Node>& theseN
 					out << theseNodes[node].getLabel();
 				}
 				//if there is a branch length then print it
-				if (theseNodes[node].getBranchLength() != -1) {
+				if (!util.isEqual(theseNodes[node].getBranchLength(), -1)) {
 					out << ":" << theseNodes[node].getBranchLength();
 				}
 			}
@@ -1059,7 +1058,7 @@ void Tree::printBranch(int node, ostream& out, string mode, vector<Node>& theseN
 			if (mode == "branch") {
 				out << leafGroup[0]; 
 				//if there is a branch length then print it
-				if (theseNodes[node].getBranchLength() != -1) {
+				if (!util.isEqual(theseNodes[node].getBranchLength(), -1)) {
 					out << ":" << theseNodes[node].getBranchLength();
 				}
 			}else if (mode == "boot") {
@@ -1074,7 +1073,7 @@ void Tree::printBranch(int node, ostream& out, string mode, vector<Node>& theseN
 					out << theseNodes[node].getLabel();
 				}
 				//if there is a branch length then print it
-				if (theseNodes[node].getBranchLength() != -1) {
+				if (!util.isEqual(theseNodes[node].getBranchLength(), -1)) {
 					out << ":" << theseNodes[node].getBranchLength();
 				}
 			}
