@@ -22,6 +22,10 @@
     #include <boost/iostreams/filter/gzip.hpp>
 #endif
 
+#ifdef USE_HDF5
+    #include "H5Cpp.h"
+#endif
+
 //io libraries
 #include <iostream>
 #include <iomanip>
@@ -100,6 +104,25 @@ using namespace std;
 #define PATH_SEPARATOR "/"
 #define EXECUTABLE_EXT ""
 #define NON_WINDOWS
+
+#define RESET   "\033[0m"
+#define BLACK   "\033[30m"      /* Black */
+#define RED     "\033[31m"      /* Red */
+#define GREEN   "\033[32m"      /* Green */
+#define YELLOW  "\033[33m"      /* Yellow */
+#define BLUE    "\033[34m"      /* Blue */
+#define MAGENTA "\033[35m"      /* Magenta */
+#define CYAN    "\033[36m"      /* Cyan */
+#define WHITE   "\033[37m"      /* White */
+#define BOLDBLACK   "\033[1m\033[30m"      /* Bold Black */
+#define BOLDRED     "\033[1m\033[31m"      /* Bold Red */
+#define BOLDGREEN   "\033[1m\033[32m"      /* Bold Green */
+#define BOLDYELLOW  "\033[1m\033[33m"      /* Bold Yellow */
+#define BOLDBLUE    "\033[1m\033[34m"      /* Bold Blue */
+#define BOLDMAGENTA "\033[1m\033[35m"      /* Bold Magenta */
+#define BOLDCYAN    "\033[1m\033[36m"      /* Bold Cyan */
+#define BOLDWHITE   "\033[1m\033[37m"      /* Bold White */
+
 #undef WINDOWS
 
 #else
@@ -154,6 +177,12 @@ struct item {
     ~item() {}
 };
 
+struct weightedSeq {
+    long long name;
+    long long weight;
+    weightedSeq(long long n, long long w)  { name = n; weight = w;     }
+};
+
 struct PCell{
     ull row;
     ull column;
@@ -175,7 +204,14 @@ struct PDistCellMin{
     //PDistCell* cell;
     PDistCellMin(ull r, ull c) :  col(c), row(r) {}
 };
+/***********************************************************************/
 
+struct colDist {
+    int col;
+    int row;
+    float dist;
+    colDist(int r, int c, double d) : row(r), col(c), dist(d) {}
+};
 /**********************************************************/
 struct CommonHeader {
 	unsigned int magicNumber;
