@@ -23,9 +23,9 @@ RandomNumberGenerator::RandomNumberGenerator(){
 
 float RandomNumberGenerator::randomUniform(){
 	
-	float randUnif = 0.0000;
+	float randUnif = 0;
 	
-	while(randUnif == 0.0000){
+	while(util.isEqual(randUnif, 0)){
 		
 		randUnif = rand() / (float)RAND_MAX;
 		
@@ -42,9 +42,9 @@ float RandomNumberGenerator::randomUniform(){
 
 float RandomNumberGenerator::randomExp(){
 	
-	float randExp = 0.0000;
+	float randExp = 0;
 	
-	while(randExp == 0.0000){
+	while(util.isEqual(randExp, 0)){
 		
 		randExp = -log(randomUniform());
 		
@@ -68,7 +68,7 @@ float RandomNumberGenerator::randomNorm(){
 		y = 2.0 * randomUniform() - 1.0;
 	
 		rsquare = x * x + y * y;
-	} while(rsquare >= 1.0 || rsquare == 0.0);
+	} while(rsquare >= 1.0 || util.isEqual(rsquare, 0));
 	
 	float fac = sqrt(-2.0 * log(rsquare)/rsquare);
 
@@ -185,7 +185,7 @@ float RandomNumberGenerator::randomGamma(float a)
     /* --- a >= 1 : GD algorithm --- */
 	
     /* Step 1: Recalculations of s2, s, d if a has changed */
-    if (a != aa) {
+    if (!util.isEqual(a, aa)) {
         aa = a;
         s2 = a - 0.5;
         s = sqrt(s2);
@@ -208,7 +208,7 @@ float RandomNumberGenerator::randomGamma(float a)
 	
     /* Step 4: recalculations of q0, b, si, c if necessary */
 	
-    if (a != aaa) {
+    if (!util.isEqual(a, aaa)) {
         aaa = a;
         r = 1.0 / a;
         q0 = ((((((q7 * r + q6) * r + q5) * r + q4) * r + q3) * r
