@@ -133,9 +133,9 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 						
 						in >> distance;
 						
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff){
+						if(distance <= cutoff){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -150,9 +150,9 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 						
 						in >> distance;
 						
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff){
+						if(distance <= cutoff){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -172,9 +172,9 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 						
 						in >> distance;
 					
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff && j < i){
+						if(distance <= cutoff && j < i){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -187,9 +187,9 @@ int ReadCluster::convertPhylip2Column(NameAssignment*& nameMap){
 						
 						in >> distance;
                         
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff && j < i){
+						if(distance <= cutoff && j < i){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 						
@@ -311,9 +311,9 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 						
 						in >> distance;
 						
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff){
+						if(distance <= cutoff){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -327,9 +327,9 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 						
 						in >> distance;
 						
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff){
+						if(distance <= cutoff){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -349,9 +349,9 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 						
 						in >> distance;
                         
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff && j < i){
+						if(distance <= cutoff && j < i){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 					}
@@ -362,9 +362,9 @@ int ReadCluster::convertPhylip2Column(CountTable*& ct){
 						
 						in >> distance;
                         
-						if (distance == -1) { distance = 1000000; }
+						if (util.isEqual(distance, -1)) { distance = 1000000; }
 						
-						if(distance < cutoff && j < i){
+						if(distance <= cutoff && j < i){
 							out << i << '\t' << j << '\t' << distance << endl;
 						}
 						
