@@ -732,12 +732,7 @@ int seqNoise::countDiffs(vector<int> query, vector<int> ref){
 				j--;
 			}
 		}
-		
-		//	cout << diffs << endl;
-		//	cout << alignA << endl;
-		//	cout << alignB << endl;
-		//	cout << endl;
-		
+				
 		return diffs;
 	}
 	catch(exception& e) {
@@ -825,8 +820,7 @@ int seqNoise::writeOutput(string fastaFileName, string namesFileName, string uMa
 			
 			if(finalTau[i] > 0){
 				
-				if(maxSequenceIndex[i] != centroids[i] && distances[maxSequenceIndex[i]*numSeqs + centroids[i]] == 0){
-					//				cout << uniqueNames[centroids[i]] << '\t' << uniqueNames[maxSequenceIndex[i]] << '\t' << count << endl;
+				if((maxSequenceIndex[i] != centroids[i]) && util.isEqual(distances[maxSequenceIndex[i]*numSeqs + centroids[i]], 0)){
 					centroids[i] = maxSequenceIndex[i];
 				}
 				
