@@ -33,27 +33,27 @@ void Summary::processNameCount(string n) { //name or count file to include in co
 bool Summary::isCountFile(string inputfile){
     try {
         bool isCount = true;
-        
+
         ifstream in;
         Utils util; util.openInputFile(inputfile, in);
-        
+
         //read headers
         string line = util.getline(in);
-        
+
         in.close();
-        
+
         vector<string> pieces = util.splitWhiteSpace(line);
-        
+
         if (pieces.size() >= 2) {
             CountTable ct;
             vector<string> defaultHeaders = ct.getHardCodedHeaders();
             if (defaultHeaders.size() >= 2) {
-                if (pieces[0] != defaultHeaders[0]) { isCount = false; }
+                if ((pieces[0] != defaultHeaders[0]) && (pieces[0] != "OTU_Label")) { isCount = false; }
                 if (pieces[1] != defaultHeaders[1]) { isCount = false; }
             }else { isCount = false; }
         }else { isCount = false; }
-        
-        
+
+
         return isCount;
     }
     catch(exception& e) {
@@ -66,17 +66,17 @@ bool Summary::isCountFile(string inputfile){
 vector<long long> Summary::getDefaults() {
     try {
         vector<long long> locations;
-        
+
         long long ptile0_25	= 1+(long long)(total * 0.025); //number of sequences at 2.5%
         long long ptile25		= 1+(long long)(total * 0.250); //number of sequences at 25%
         long long ptile50		= 1+(long long)(total * 0.500);
         long long ptile75		= 1+(long long)(total * 0.750);
         long long ptile97_5	= 1+(long long)(total * 0.975);
         long long ptile100	= (long long)(total);
-        
+
         locations.push_back(1); locations.push_back(ptile0_25); locations.push_back(ptile25); locations.push_back(ptile50);
         locations.push_back(ptile75); locations.push_back(ptile97_5); locations.push_back(ptile100);
-        
+
         return locations;
     }
     catch(exception& e) {
@@ -92,12 +92,12 @@ vector<long long> Summary::getValues(map<int, long long>& positions) {
         long long meanPosition; meanPosition = 0;
         long long totalSoFar = 0;
         int lastValue = 0;
-        
+
         //minimum
         if ((positions.begin())->first == -1) { results[0] = 0; }
         else {results[0] = (positions.begin())->first; }
         results[1] = results[0]; results[2] = results[0]; results[3] = results[0]; results[4] = results[0]; results[5] = results[0];
-        
+
         for (map<int, long long>::iterator it = positions.begin(); it != positions.end(); it++) {
             int value = it->first; if (value == -1) { value = 0; }
             meanPosition += (value*it->second);
@@ -111,10 +111,10 @@ vector<long long> Summary::getValues(map<int, long long>& positions) {
             lastValue = totalSoFar;
         }
         results[6] = (positions.rbegin())->first;
-        
+
         double meansPosition = meanPosition / (double) total;
         results.push_back(meansPosition);
-        
+
         return results;
     }
     catch(exception& e) {
@@ -129,19 +129,19 @@ long long Summary::getValue(map<int, long long>& spots, double value) {
         long long result = 0;
         long long totalSoFar = 0;
         long long lastValue = 0;
-        
+
         //minimum
         if ((spots.begin())->first == -1) { result = 0; }
         else {result = (spots.begin())->first; }
-    
+
         for (it = spots.begin(); it != spots.end(); it++) {
             long long value = it->first; if (value == -1) { value = 0; }
             totalSoFar += it->second;
-            
+
             if (((totalSoFar <= percentage) && (totalSoFar > 1)) || ((lastValue < percentage) && (totalSoFar > percentage))){  result = value;   } //save value
             lastValue = totalSoFar;
         }
-        
+
         return result;
     }
     catch(exception& e) {
@@ -157,12 +157,12 @@ vector<long long> Summary::getValues(map<float, long long>& positions) {
         long long meanPosition; meanPosition = 0;
         long long totalSoFar = 0;
         int lastValue = 0;
-        
+
         //minimum
-        if ((positions.begin())->first == -1) { results[0] = 0; }
+        if (util.isEqual((positions.begin())->first, -1)) { results[0] = 0; }
         else {results[0] = (positions.begin())->first; }
         results[1] = results[0]; results[2] = results[0]; results[3] = results[0]; results[4] = results[0]; results[5] = results[0];
-        
+
         for (map<float, long long>::iterator it = positions.begin(); it != positions.end(); it++) {
             long long value = it->first; if (value == -1) { value = 0; }
             meanPosition += (value*it->second);
@@ -176,10 +176,10 @@ vector<long long> Summary::getValues(map<float, long long>& positions) {
             lastValue = totalSoFar;
         }
         results[6] = (positions.rbegin())->first;
-        
+
         double meansPosition = meanPosition / (double) total;
         results.push_back(meansPosition);
-        
+
         return results;
     }
     catch(exception& e) {
@@ -194,19 +194,19 @@ long long Summary::getValue(map<float, long long>& positions, double value) {
         long long result = 0;
         long long totalSoFar = 0;
         long long lastValue = 0;
-        
+
         //minimum
-        if ((positions.begin())->first == -1) { result = 0; }
+        if (util.isEqual((positions.begin())->first, -1)) { result = 0; }
         else { result = (positions.begin())->first; }
-        
+
         for (map<float, long long>::iterator it = positions.begin(); it != positions.end(); it++) {
             long long value = it->first; if (value == -1) { value = 0; }
             totalSoFar += it->second;
-            
+
             if (((totalSoFar <= percentage) && (totalSoFar > 1)) || ((lastValue < percentage) && (totalSoFar > percentage))){  result = value;   } //save value
             lastValue = totalSoFar;
         }
-        
+
         return result;
     }
     catch(exception& e) {
@@ -214,7 +214,25 @@ long long Summary::getValue(map<float, long long>& positions, double value) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
+
+//**************************************************************************************************
+
+int Summary::getMaxAbundance(){
+
+	int max = 0;
+
+	for(map<string,int>::iterator it=nameMap.begin();it!=nameMap.end();it++){
+		if(it->second > max){
+			max = it->second;
+		}
+	}
+
+	return max;
+
+}
+
+//**************************************************************************************************
+
 long long Summary::summarizeFasta(string fastafile, string n, string output) {
     try {
         //fill namemap
@@ -231,86 +249,86 @@ void driverSummarize(seqSumData* params) { //(string fastafile, string output, l
     try {
         ofstream out;
         if (params->summaryFile != "") { params->util.openOutputFile(params->summaryFile, out); }
-        
+
         ifstream in;
         params->util.openInputFile(params->filename, in);
-        
+
         in.seekg(params->start);
-        
+
         //print header if you are process 0
         if (params->start == 0) {
             params->util.zapGremlins(in); params->util.gobble(in);
             //print header if you are process 0
             if (params->summaryFile != "") { out << "seqname\tstart\tend\tnbases\tambigs\tpolymer\tnumSeqs" << endl; }
         }
-        
+
         bool done = false;
         params->count = 0;
-        
+
         while (!done) {
-            
+
             if (params->m->getControl_pressed()) {  break; }
-            
+
             Sequence seq(in); params->util.gobble(in);
-            
+
             if (seq.getName() != "") {
-                
+
                 if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + seq.getName() + "\t" + toString(seq.getStartPos()) + "\t" + toString(seq.getEndPos()) + "\t" + toString(seq.getNumBases()) + "\n"); }
-                
+
                 //string seqInfo = addSeq(current);
                 params->count++;
-                
+
                 long long num = 1;
-                
+
                 if (params->hasNameMap) {
                     //make sure this sequence is in the namefile, else error
                     map<string, int>::iterator itFindName = params->nameMap.find(seq.getName());
-                    
+
                     if (itFindName == params->nameMap.end()) { params->m->mothurOut("[ERROR]: '" + seq.getName() + "' is not in your name or count file, please correct."); params->m->mothurOutEndLine(); params->m->setControl_pressed(true); }
                     else { num = itFindName->second; }
                 }
-                
+
                 int thisStartPosition = seq.getStartPos();
                 map<int, long long>::iterator it = params->startPosition.find(thisStartPosition);
                 if (it == params->startPosition.end()) { params->startPosition[thisStartPosition] = num; } //first finding of this start position, set count.
                 else { it->second += num; } //add counts
-                
+
                 int thisEndPosition = seq.getEndPos();
                 it = params->endPosition.find(thisEndPosition);
                 if (it == params->endPosition.end()) { params->endPosition[thisEndPosition] = num; } //first finding of this end position, set count.
                 else { it->second += num; } //add counts
-                
+
                 int thisSeqLength = seq.getNumBases();
                 it = params->seqLength.find(thisSeqLength);
                 if (it == params->seqLength.end()) { params->seqLength[thisSeqLength] = num; } //first finding of this length, set count.
                 else { it->second += num; } //add counts
-                
+
                 int thisAmbig = seq.getAmbigBases();
                 it = params->ambigBases.find(thisAmbig);
                 if (it == params->ambigBases.end()) { params->ambigBases[thisAmbig] = num; } //first finding of this ambig, set count.
                 else { it->second += num; } //add counts
-                
+
                 int thisHomoP = seq.getLongHomoPolymer();
                 it = params->longHomoPolymer.find(thisHomoP);
                 if (it == params->longHomoPolymer.end()) { params->longHomoPolymer[thisHomoP] = num; } //first finding of this homop, set count.
                 else { it->second += num; } //add counts
-                
+
                 int numns = seq.getNumNs();
                 it = params->numNs.find(numns);
                 if (it == params->numNs.end()) { params->numNs[numns] = num; } //first finding of this homop, set count.
                 else { it->second += num; } //add counts
-                
+
                 params->total += num;
-                
+
                 string seqInfo = "";
                 seqInfo += seq.getName() + '\t';
                 seqInfo += toString(thisStartPosition) + '\t' + toString(thisEndPosition) + '\t';
                 seqInfo += toString(thisSeqLength) + '\t' + toString(thisAmbig) + '\t';
                 seqInfo += toString(thisHomoP) + '\t' + toString(num);
-                
+
                 if (params->summaryFile != "") { out << seqInfo << endl; }
             }
-            
+
 #if defined NON_WINDOWS
             unsigned long long pos = in.tellg();
             if ((pos == -1) || (pos >= params->end)) { break; }
@@ -318,10 +336,10 @@ void driverSummarize(seqSumData* params) { //(string fastafile, string output, l
             if (params->count == params->end) { break; }
 #endif
         }
-        
+
         if (params->summaryFile != "") { out.close(); }
         in.close();
-        
+
     }
     catch(exception& e) {
         params->m->errorOut(e, "Summary", "driverSummarize");
@@ -340,7 +358,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
 #else
         positions = util.setFilePosFasta(fastafile, num);
         if (num < processors) { processors = num; }
-        
+
         //figure out how many sequences you have to process
         int numSeqsPerProcessor = num / processors;
         for (int i = 0; i < processors; i++) {
@@ -349,7 +367,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
             lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
         }
 #endif
-        
+
         //create array of worker threads
         vector<thread*> workerThreads;
         vector<seqSumData*> data;
@@ -360,15 +378,15 @@ long long Summary::summarizeFasta(string fastafile, string output) {
             extension = toString(i) + ".temp";
             string outputName = output + extension;
             if (output == "") {  outputName = "";  }
-            
+
             seqSumData* dataBundle = new seqSumData(fastafile, outputName, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
-            
+
             workerThreads.push_back(new thread(driverSummarize, dataBundle));
         }
-        
+
         seqSumData* dataBundle = new seqSumData(fastafile, output, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
-        
+
         driverSummarize(dataBundle);
         num = dataBundle->count;
         total = dataBundle->total;
@@ -379,12 +397,12 @@ long long Summary::summarizeFasta(string fastafile, string output) {
         longHomoPolymer = dataBundle->longHomoPolymer;
         numNs = dataBundle->numNs;
         delete dataBundle;
-        
+
         for (int i = 0; i < processors-1; i++) {
             workerThreads[i]->join();
             num += data[i]->count;
             total += data[i]->total;
-            
+
             for (map<int, long long>::iterator it = data[i]->startPosition.begin(); it != data[i]->startPosition.end(); it++)		{
                 map<int, long long>::iterator itMain = startPosition.find(it->first);
                 if (itMain == startPosition.end()) { //newValue
@@ -425,7 +443,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
             delete data[i];
             delete workerThreads[i];
         }
-        
+
         //append files
         for (int i = 0; i < processors-1; i++) {
             string extension = "";
@@ -438,17 +456,17 @@ long long Summary::summarizeFasta(string fastafile, string output) {
                 util.mothurRemove((output + toString(i) + ".temp"));
             }
         }
-        
+
         if (hasNameOrCount) {
             if (nameCountNumUniques != num) { // do fasta and name/count files match
                 m->mothurOut("[ERROR]: Your " + type + " file contains " + toString(nameCountNumUniques) + " unique sequences, but your fasta file contains " + toString(num) + ". File mismatch detected, quitting command.\n"); m->setControl_pressed(true);
             }
         }
-        
+
         numUniques = num;
-        
+
         return num;
-        
+
     }
     catch(exception& e) {
         m->errorOut(e, "Summary", "summarizeFasta");
@@ -472,59 +490,59 @@ void driverFastaSummarySummarize(seqSumData* params) {
     try {
         ifstream in;
         params->util.openInputFile(params->filename, in);
-        
+
         in.seekg(params->start);
-        
+
         //print header if you are process 0
         if (params->start == 0) { params->util.zapGremlins(in); params->util.getline(in); params->util.gobble(in); params->count++; }
-        
+
         bool done = false;
         string name;
         int start, end, length, ambigs, polymer;
         long long numReps;
-        
+
         while (!done) {
-            
+
             if (params->m->getControl_pressed()) {  break; }
-            
+
             //seqname	start	end	nbases	ambigs	polymer	numSeqs
             in >> name >> start >> end >> length >> ambigs >> polymer >> numReps; params->util.gobble(in);
-            
+
             if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + name + "\t" + toString(start) + "\t" + toString(end) + "\t" + toString(length) + "\n"); }
-            
+
             if (name != "") {
                 if ((numReps == 1) && params->hasNameMap) {
                     //make sure this sequence is in the namefile, else error
                     map<string, int>::iterator itFindName = params->nameMap.find(name);
-                    
+
                     if (itFindName == params->nameMap.end()) { params->m->mothurOut("[ERROR]: '" + name + "' is not in your name or count file, please correct."); params->m->mothurOutEndLine(); params->m->setControl_pressed(true); }
                     else { numReps = itFindName->second; }
                 }
-                
+
                 map<int, long long>::iterator it = params->startPosition.find(start);
                 if (it == params->startPosition.end()) { params->startPosition[start] = numReps; } //first finding of this start position, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->endPosition.find(end);
                 if (it == params->endPosition.end()) { params->endPosition[end] = numReps; } //first finding of this end position, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->seqLength.find(length);
                 if (it == params->seqLength.end()) { params->seqLength[length] = numReps; } //first finding of this length, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->ambigBases.find(ambigs);
                 if (it == params->ambigBases.end()) { params->ambigBases[ambigs] = numReps; } //first finding of this ambig, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->longHomoPolymer.find(polymer);
                 if (it == params->longHomoPolymer.end()) { params->longHomoPolymer[polymer] = numReps; } //first finding of this homop, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 params->count++;
                 params->total += numReps;
             }
-            
+
 #if defined NON_WINDOWS
             unsigned long long pos = in.tellg();
             if ((pos == -1) || (pos >= params->end)) { break; }
@@ -532,9 +550,9 @@ void driverFastaSummarySummarize(seqSumData* params) {
             if (params->end == params->count) { break; }
 #endif
         }
-        
+
         in.close();
-        
+
     }
     catch(exception& e) {
         params-> m->errorOut(e, "Summary", "driverFastaSummarySummarize");
@@ -553,7 +571,7 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
 #else
         positions = util.setFilePosEachLine(summaryfile, num);
         if (num < processors) { processors = num; }
-        
+
         //figure out how many sequences you have to process
         int numSeqsPerProcessor = num / processors;
         for (int i = 0; i < processors; i++) {
@@ -562,21 +580,21 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
             lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
         }
 #endif
-        
+
         //create array of worker threads
         vector<thread*> workerThreads;
         vector<seqSumData*> data;
-        
+
         //Lauch worker threads
         for (int i = 0; i < processors-1; i++) {
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
-            
+
             workerThreads.push_back(new thread(driverFastaSummarySummarize, dataBundle));
         }
-        
+
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
-        
+
         driverFastaSummarySummarize(dataBundle);
         num = dataBundle->count-1; //header line
         total = dataBundle->total;
@@ -586,12 +604,12 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
         ambigBases = dataBundle->ambigBases;
         longHomoPolymer = dataBundle->longHomoPolymer;
         delete dataBundle;
-        
+
         for (int i = 0; i < processors-1; i++) {
             workerThreads[i]->join();
             num += data[i]->count;
             total += data[i]->total;
-            
+
             for (map<int, long long>::iterator it = data[i]->startPosition.begin(); it != data[i]->startPosition.end(); it++)		{
                 map<int, long long>::iterator itMain = startPosition.find(it->first);
                 if (itMain == startPosition.end()) { //newValue
@@ -622,20 +640,20 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
                     longHomoPolymer[it->first] = it->second;
                 }else { itMain->second += it->second; } //merge counts
             }
-            
+
             delete data[i];
             delete workerThreads[i];
         }
-        
-        
+
+
         if (hasNameOrCount) {
             if (nameCountNumUniques != num) { // do fasta and name/count files match
                 m->mothurOut("[ERROR]: Your " + type + " file contains " + toString(nameCountNumUniques) + " unique sequences, but your fasta file contains " + toString(num) + ". File mismatch detected, quitting command.\n"); m->setControl_pressed(true);
             }
         }
-        
+
         numUniques = num;
-        
+
         return num;
 
     }
@@ -661,63 +679,64 @@ void driverContigsSummarySummarize(seqSumData* params) {
     try {
         ifstream in;
         params->util.openInputFile(params->filename, in);
-        
+
         in.seekg(params->start);
-        
+
         //print header if you are process 0
         if (params->start == 0) { params->util.zapGremlins(in); params->util.getline(in); params->util.gobble(in); params->count++; }
-        
+
         bool done = false;
         string name;
         int length, OLength, thisOStart, thisOEnd, numMisMatches, numns; //Name	Length	Overlap_Length	Overlap_Start	Overlap_End	MisMatches	Num_Ns
-        
+        double expectedErrors;
+
         while (!done) {
-            
+
             if (params->m->getControl_pressed()) { break; }
-            
+
             //seqname	start	end	nbases	ambigs	polymer	numSeqs
-            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numns; params->util.gobble(in);
-            
+            in >> name >> length >> OLength >> thisOStart >> thisOEnd >> numMisMatches >> numns >> expectedErrors; params->util.gobble(in);
+
             if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + name + "\t" + toString(thisOStart) + "\t" + toString(thisOEnd) + "\t" + toString(length) + "\n"); }
-            
+
             if (name != "") {
                 long long numReps = 1;
                 if (params->hasNameMap) {
                     //make sure this sequence is in the namefile, else error
                     map<string, int>::iterator itFindName = params->nameMap.find(name);
-                    
+
                     if (itFindName == params->nameMap.end()) { params->m->mothurOut("[ERROR]: '" + name + "' is not in your name or count file, please correct."); params->m->mothurOutEndLine(); params->m->setControl_pressed(true); }
                     else { numReps = itFindName->second; }
                 }
-                
+
                 map<int, long long>::iterator it = params->ostartPosition.find(thisOStart);
                 if (it == params->ostartPosition.end()) { params->ostartPosition[thisOStart] = numReps; } //first finding of this start position, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->oendPosition.find(thisOEnd);
                 if (it == params->oendPosition.end()) { params->oendPosition[thisOEnd] = numReps; } //first finding of this end position, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->oseqLength.find(OLength);
                 if (it == params->oseqLength.end()) { params->oseqLength[OLength] = numReps; } //first finding of this length, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->seqLength.find(length);
                 if (it == params->seqLength.end()) { params->seqLength[length] = numReps; } //first finding of this length, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->misMatches.find(numMisMatches);
                 if (it == params->misMatches.end()) { params->misMatches[numMisMatches] = numReps; } //first finding of this ambig, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->numNs.find(numns);
                 if (it == params->numNs.end()) { params->numNs[numns] = numReps; } //first finding of this homop, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 params->count++;
                 params->total += numReps;
             }
-            
+
 #if defined NON_WINDOWS
             unsigned long long pos = in.tellg();
             if ((pos == -1) || (pos >= params->end)) { break; }
@@ -725,7 +744,7 @@ void driverContigsSummarySummarize(seqSumData* params) {
             if (params->end == params->count) { break; }
 #endif
         }
-        
+
         in.close();
     }
     catch(exception& e) {
@@ -745,7 +764,7 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
 #else
         positions = util.setFilePosEachLine(summaryfile, num);
         if (num < processors) { processors = num; }
-        
+
         //figure out how many sequences you have to process
         int numSeqsPerProcessor = num / processors;
         for (int i = 0; i < processors; i++) {
@@ -754,22 +773,22 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
             lines.push_back(linePair(positions[startIndex], numSeqsPerProcessor));
         }
 #endif
-        
+
         //create array of worker threads
         vector<thread*> workerThreads;
         vector<seqSumData*> data;
-        
+
         //Lauch worker threads
         for (int i = 0; i < processors-1; i++) {
             if (m->getDebug()) { m->mothurOut("[DEBUG]: creating thread " + toString(i+1) + "\n"); }
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
-            
+
             workerThreads.push_back(new thread(driverContigsSummarySummarize, dataBundle));
         }
-        
+
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
-        
+
         driverContigsSummarySummarize(dataBundle);
         num = dataBundle->count-1; //header line
         total = dataBundle->total;
@@ -780,14 +799,14 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
         misMatches = dataBundle->misMatches;
         numNs = dataBundle->numNs;
         delete dataBundle;
-        
-        
+
+
         for (int i = 0; i < processors-1; i++) {
             workerThreads[i]->join();
             num += data[i]->count;
             total += data[i]->total;
-            
-            
+
+
             for (map<int, long long>::iterator it = data[i]->ostartPosition.begin(); it != data[i]->ostartPosition.end(); it++)		{
                 map<int, long long>::iterator itMain = ostartPosition.find(it->first);
                 if (itMain == ostartPosition.end()) { //newValue
@@ -824,20 +843,20 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
                     numNs[it->first] = it->second;
                 }else { itMain->second += it->second; } //merge counts
             }
-            
+
             delete data[i];
             delete workerThreads[i];
         }
-        
-        
+
+
         if (hasNameOrCount) {
             if (nameCountNumUniques != num) { // do fasta and name/count files match
                 m->mothurOut("[ERROR]: Your " + type + " file contains " + toString(nameCountNumUniques) + " unique sequences, but your fasta file contains " + toString(num) + ". File mismatch detected, quitting command.\n"); m->setControl_pressed(true);
             }
         }
-        
+
         numUniques = num;
-        
+
         return num;
     }
     catch(exception& e) {
@@ -862,58 +881,58 @@ void driverAlignSummarySummarize(seqSumData* params) {
     try {
         ifstream in;
         params->util.openInputFile(params->filename, in);
-        
+
         in.seekg(params->start);
-        
+
         //print header if you are process 0
         if (params->start == 0) { params->util.zapGremlins(in); params->util.getline(in); params->util.gobble(in); params->count++; }
-        
+
         bool done = false;
         string name, TemplateName, SearchMethod, AlignmentMethod;
         int length, TemplateLength,	 QueryStart,	QueryEnd,	TemplateStart,	TemplateEnd,	PairwiseAlignmentLength,	GapsInQuery,	GapsInTemplate,	LongestInsert;
         float SearchScore, SimBtwnQueryTemplate;
-        
+
         while (!done) {
-            
+
             if (params->m->getControl_pressed()) {  break; }
-            
+
             in >> name >> length >> TemplateName >> TemplateLength >> SearchMethod >> SearchScore >> AlignmentMethod >> QueryStart >> QueryEnd >> TemplateStart >> TemplateEnd >> PairwiseAlignmentLength >> GapsInQuery >> GapsInTemplate >> LongestInsert >> SimBtwnQueryTemplate; params->util.gobble(in);
-            
-            
+
+
             if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + name + "\t" + toString(TemplateName) + "\t" + toString(SearchScore) + "\t" + toString(length) + "\n"); }
-            
+
             if (name != "") {
                 //string seqInfo = addSeq(name, length, SimBtwnQueryTemplate, SearchScore, LongestInsert);
                 long long numReps = 1;
                 if (params->hasNameMap) {
                     //make sure this sequence is in the namefile, else error
                      map<string, int>::iterator itFindName = params->nameMap.find(name);
-                    
+
                     if (itFindName == params->nameMap.end()) { params->m->mothurOut("[ERROR]: '" + name + "' is not in your name or count file, please correct."); params->m->mothurOutEndLine(); params->m->setControl_pressed(true); }
                     else { numReps = itFindName->second; }
                 }
-                
+
                 map<float, long long>:: iterator itFloat = params->sims.find(SimBtwnQueryTemplate);
                 if (itFloat == params->sims.end()) { params->sims[SimBtwnQueryTemplate] = numReps; } //first finding of this similarity score, set count.
                 else { itFloat->second += numReps; } //add counts
-                
+
                 itFloat = params->scores.find(SearchScore);
                 if (itFloat == params->scores.end()) { params->scores[SearchScore] = numReps; } //first finding of this end position, set count.
                 else { itFloat->second += numReps; } //add counts
-                
+
                 map<int, long long>::iterator it = params->inserts.find(LongestInsert);
                 if (it == params->inserts.end()) { params->inserts[LongestInsert] = numReps; } //first finding of this length, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 it = params->seqLength.find(length);
                 if (it == params->seqLength.end()) { params->seqLength[length] = numReps; } //first finding of this length, set count.
                 else { it->second += numReps; } //add counts
-                
+
                 params->count++;
                 params->total += numReps;
 
             }
-            
+
 #if defined NON_WINDOWS
             unsigned long long pos = in.tellg();
             if ((pos == -1) || (pos >= params->end)) { break; }
@@ -921,7 +940,7 @@ void driverAlignSummarySummarize(seqSumData* params) {
             if (params->end == params->count) { break; }
 #endif
         }
-        
+
         in.close();
     }
     catch(exception& e) {
@@ -941,7 +960,7 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
 #else
         positions = util.setFilePosEachLine(summaryfile, num);
         if (num < processors) { processors = num; }
-        
+
         //figure out how many sequences you have to process
         int numSeqsPerProcessor = num / processors;
         for (int i = 0; i < processors; i++) {
@@ -953,18 +972,18 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
         //create array of worker threads
         vector<thread*> workerThreads;
         vector<seqSumData*> data;
-        
+
         //Lauch worker threads
         for (int i = 0; i < processors-1; i++) {
-            
+
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
-            
+
             workerThreads.push_back(new thread(driverAlignSummarySummarize, dataBundle));
         }
-        
+
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
-        
+
         driverAlignSummarySummarize(dataBundle);
         num = dataBundle->count-1; //header line
         total = dataBundle->total;
@@ -973,12 +992,12 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
         inserts = dataBundle->inserts;
         seqLength = dataBundle->seqLength;
         delete dataBundle;
-        
+
         for (int i = 0; i < processors-1; i++) {
             workerThreads[i]->join();
             num += data[i]->count;
             total += data[i]->total;
-            
+
             for (map<float, long long>::iterator it = data[i]->sims.begin(); it != data[i]->sims.end(); it++)		{
                 map<float, long long>::iterator itMain = sims.find(it->first);
                 if (itMain == sims.end()) { //newValue
@@ -1003,20 +1022,20 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
                     seqLength[it->first] = it->second;
                 }else { itMain->second += it->second; } //merge counts
             }
-            
+
             delete data[i];
             delete workerThreads[i];
         }
-        
-        
+
+
         if (hasNameOrCount) {
             if (nameCountNumUniques != num) { // do fasta and name/count files match
                 m->mothurOut("[ERROR]: Your " + type + " file contains " + toString(nameCountNumUniques) + " unique sequences, but your fasta file contains " + toString(num) + ". File mismatch detected, quitting command.\n"); m->setControl_pressed(true);
             }
         }
-        
+
         numUniques = num;
-        
+
         return num;
     }
     catch(exception& e) {
@@ -1025,10 +1044,3 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
     }
 }
 //**********************************************************************************************************************
-
-
-
-
-
-
-
