@@ -23,7 +23,7 @@ class TrimOligos {
 #endif
 	
 	public:
-        TrimOligos(int,int,int, map<string, int>, map<string, int>, vector<string>); //pdiffs, bdiffs, primers, barcodes, revPrimers
+        TrimOligos(int,int,int, map<string, int>, map<string, int>, vector<string>); //pdiffs, rpdiffs, bdiffs, primers, barcodes, revPrimers
         TrimOligos(int,int, int, int, map<string, int>, map<string, int>, vector<string>, vector<string>, vector<string>); //pdiffs, bdiffs, ldiffs, sdiffs, primers, barcodes, revPrimers, linker, spacer
         TrimOligos(int,int, int, int, map<int, oligosPair>, map<int, oligosPair>, bool); //pdiffs, bdiffs, ldiffs, sdiffs, primers, barcodes, hasIndex
     ~TrimOligos(){}
@@ -45,11 +45,11 @@ class TrimOligos {
 		vector<int> stripReverse(Sequence&);
 		vector<int> stripReverse(Sequence&, QualityScores&);
     
-        bool stripLinker(Sequence&);
-        bool stripLinker(Sequence&, QualityScores&);
+        int stripLinker(Sequence&);
+        int stripLinker(Sequence&, QualityScores&);
     
-        bool stripSpacer(Sequence&);
-        bool stripSpacer(Sequence&, QualityScores&);
+        int stripSpacer(Sequence&);
+        int stripSpacer(Sequence&, QualityScores&);
     
         //seq, primerStart, primerEnd
         vector<int> findForward(Sequence&, int&, int&);
